(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    183613,       4128]
NotebookOptionsPosition[    179530,       4004]
NotebookOutlinePosition[    181148,       4054]
CellTagsIndexPosition[    180812,       4042]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Geodesics on some surfaces with NDSolve\
\>", "DemoTitle",
 CellChangeTimes->{3.605139489358591*^9}],

Cell[CellGroupData[{

Cell["", "InitializationSection"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Parametrization", " ", "of", " ", "different", " ", "surfaces"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"monkeysaddle", "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
     RowBox[{"{", 
      RowBox[{"u", ",", "v", ",", 
       RowBox[{
        RowBox[{"u", "^", "3"}], "-", 
        RowBox[{"3", "*", "u", "*", 
         RowBox[{"v", "^", "2"}]}]}]}], "}"}]}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}], "x", 
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}]}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"torus", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_"}], "]"}], "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"b", "+", " ", 
          RowBox[{"a", " ", 
           RowBox[{"Cos", "[", "u", "]"}]}]}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", "v", "]"}], 
        RowBox[{"(", 
         RowBox[{"b", "+", " ", 
          RowBox[{"a", " ", 
           RowBox[{"Cos", "[", "u", "]"}]}]}], ")"}]}], ",", 
       RowBox[{"c", "*", 
        RowBox[{"Sin", "[", "u", "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"helicoid", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_"}], "]"}], "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "*", "v", "*", 
        RowBox[{"Cos", "[", "u", "]"}]}], ",", 
       RowBox[{"b", "*", "v", "*", 
        RowBox[{"Sin", "[", "u", "]"}]}], ",", 
       RowBox[{"c", "*", "u"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"exptwist", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_"}], "]"}], "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "*", "v", "*", 
        RowBox[{"Cos", "[", "u", "]"}]}], ",", 
       RowBox[{"a", "*", "v", "*", 
        RowBox[{"Sin", "[", "u", "]"}]}], ",", 
       RowBox[{"a", "*", 
        RowBox[{"Exp", "[", 
         RowBox[{"c", "*", "u"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"sphere", "[", "a_", "]"}], ":=", 
     RowBox[{"torus", "[", 
      RowBox[{"a", ",", "0", ",", "a"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"paraboloid", "[", 
       RowBox[{"a_", ",", "b_"}], "]"}], "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
     RowBox[{"{", 
      RowBox[{"u", ",", "v", ",", 
       RowBox[{
        RowBox[{"a", "*", 
         RowBox[{"u", "^", "2"}]}], "+", 
        RowBox[{"b", "*", 
         RowBox[{"v", "^", "2"}]}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"elipsoid", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_"}], "]"}], "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "*", 
        RowBox[{"Sin", "[", "u", "]"}], "*", 
        RowBox[{"Cos", "[", "v", "]"}]}], ",", 
       RowBox[{"b", "*", 
        RowBox[{"Sin", "[", "u", "]"}], "*", 
        RowBox[{"Sin", "[", "v", "]"}]}], ",", 
       RowBox[{"c", "*", 
        RowBox[{"Cos", "[", "u", "]"}]}]}], "}"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"shoe", "[", 
       RowBox[{"a_", ",", "b_"}], "]"}], "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", "b"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"4", "a"}], ")"}]}], ")"}], "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "3"}], ")"}]}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"u", "-", "v"}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"2", "/", "3"}], ")"}]}]}], ",", 
       RowBox[{
        RowBox[{"-", "u"}], "-", "v"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"b", "/", "4"}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u", "^", "2"}], "+", 
          RowBox[{"14", "*", "u", "*", "v"}], "+", 
          RowBox[{"v", "^", "2"}]}], ")"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"funnel", "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"u", "*", 
        RowBox[{"Cos", "[", "v", "]"}]}], ",", 
       RowBox[{"u", "*", 
        RowBox[{"Sin", "[", "v", "]"}]}], ",", 
       RowBox[{"Log", "[", "u", "]"}]}], "}"}]}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"0", ",", "infty"}], ")"}], "x", 
      RowBox[{"(", 
       RowBox[{"0", ",", 
        RowBox[{"2", "Pi"}]}], ")"}]}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"enneper", "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"u", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{
            RowBox[{"u", "^", "2"}], "/", "3"}], "+", 
           RowBox[{"v", "^", "2"}]}], ")"}], "/", "3"}]}], ",", 
       RowBox[{
        RowBox[{"-", "v"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{
            RowBox[{"v", "^", "2"}], "/", "3"}], "+", 
           RowBox[{"u", "^", "2"}]}], ")"}], "/", "3"}]}], ",", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u", "^", "2"}], "-", 
          RowBox[{"v", "^", "2"}]}], ")"}], "/", "3"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"klein", "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"u", "/", "2"}], "]"}], 
           RowBox[{"Sin", "[", "v", "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"u", "/", "2"}], "]"}], 
           RowBox[{"Sin", "[", 
            RowBox[{"2", "v"}], "]"}]}]}], ")"}], 
        RowBox[{"Cos", "[", "u", "]"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"u", "/", "2"}], "]"}], 
           RowBox[{"Sin", "[", "v", "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"u", "/", "2"}], "]"}], 
           RowBox[{"Sin", "[", 
            RowBox[{"2", "v"}], "]"}]}]}], ")"}], 
        RowBox[{"Sin", "[", "u", "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"u", "/", "2"}], "]"}], 
         RowBox[{"Sin", "[", "v", "]"}]}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"u", "/", "2"}], "]"}], 
         RowBox[{"Sin", "[", 
          RowBox[{"2", "v"}], "]"}]}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"moebius", "[", "a_", "]"}], "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", 
          RowBox[{"u", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"v", "/", "2"}], "]"}]}]}], ")"}], 
        RowBox[{"Cos", "[", "v", "]"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", 
          RowBox[{"u", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"v", "/", "2"}], "]"}]}]}], ")"}], 
        RowBox[{"Sin", "[", "v", "]"}]}], ",", 
       RowBox[{"u", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"v", "/", "2"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Calculating", " ", "first", " ", "fundamental", " ", "form"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"metric", "[", "x_", "]"}], "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xu", ",", "xv", ",", "U", ",", "V", ",", "si"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"si", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"Simplify", "[", "#", "]"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"U", "\[Rule]", "u"}], ",", 
             RowBox[{"V", "\[Rule]", "v"}]}], "}"}]}], "&"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"xu", "=", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"x", "[", 
            RowBox[{"U", ",", "V"}], "]"}], ",", "U"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"xv", "=", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"x", "[", 
            RowBox[{"U", ",", "V"}], "]"}], ",", "V"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"ee", "=", 
         RowBox[{
          RowBox[{"xu", ".", "xu"}], "//", "si"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"ff", "=", 
         RowBox[{
          RowBox[{"xu", ".", "xv"}], "//", "si"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"gg", "=", 
         RowBox[{
          RowBox[{"xv", ".", "xv"}], "//", "si"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"ee", ",", "ff"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"ff", ",", "gg"}], "}"}]}], "}"}]}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Function", " ", "calculating", " ", "Christoffel", " ", "coefficients"}],
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"christoff", "[", "M_", "]"}], "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "AA", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"si", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"Simplify", "[", "#", "]"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"U", "\[Rule]", "u"}], ",", 
             RowBox[{"V", "\[Rule]", "v"}]}], "}"}]}], "&"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"ee", "=", 
         RowBox[{
          RowBox[{"M", "[", 
           RowBox[{"U", ",", "V"}], "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"ff", "=", 
         RowBox[{
          RowBox[{"M", "[", 
           RowBox[{"U", ",", "V"}], "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"gg", "=", 
         RowBox[{
          RowBox[{"M", "[", 
           RowBox[{"U", ",", "V"}], "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"AA", "[", 
          RowBox[{"1", ",", "1", ",", "1"}], "]"}], "=", 
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{"ee", ",", "V"}], "]"}], "ff"}], "-", 
          RowBox[{"2", 
           RowBox[{"D", "[", 
            RowBox[{"ff", ",", "U"}], "]"}], "ff"}], "+", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{"ee", ",", "U"}], "]"}], "gg"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"AA", "[", 
          RowBox[{"2", ",", "2", ",", "2"}], "]"}], "=", 
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{"gg", ",", "V"}], "]"}], "ee"}], "-", 
          RowBox[{"2", 
           RowBox[{"D", "[", 
            RowBox[{"ff", ",", "V"}], "]"}], "ff"}], "+", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{"gg", ",", "U"}], "]"}], "ff"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"AA", "[", 
          RowBox[{"2", ",", "1", ",", "1"}], "]"}], "=", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"D", "[", 
             RowBox[{"ee", ",", "V"}], "]"}]}], "ee"}], "+", 
          RowBox[{"2", 
           RowBox[{"D", "[", 
            RowBox[{"ff", ",", "U"}], "]"}], "ee"}], "-", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{"ee", ",", "U"}], "]"}], "ff"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"AA", "[", 
          RowBox[{"1", ",", "2", ",", "2"}], "]"}], "=", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"D", "[", 
             RowBox[{"gg", ",", "V"}], "]"}]}], "ff"}], "+", 
          RowBox[{"2", 
           RowBox[{"D", "[", 
            RowBox[{"ff", ",", "V"}], "]"}], "gg"}], "-", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{"gg", ",", "U"}], "]"}], "gg"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"AA", "[", 
          RowBox[{"1", ",", "1", ",", "2"}], "]"}], "=", 
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{"ee", ",", "V"}], "]"}], "gg"}], "-", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{"gg", ",", "U"}], "]"}], "ff"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"AA", "[", 
          RowBox[{"2", ",", "1", ",", "2"}], "]"}], "=", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"D", "[", 
             RowBox[{"ee", ",", "V"}], "]"}]}], "ff"}], "+", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{"gg", ",", "U"}], "]"}], "ee"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"AA", "[", 
          RowBox[{"1", ",", "2", ",", "1"}], "]"}], "=", "0"}], ";", " ", 
        RowBox[{"(*", 
         RowBox[{
         "we", " ", "are", " ", "creating", " ", "artificial", " ", 
          "coefficient", " ", "to", " ", "use", " ", "natural", " ", 
          "\"\<Christoffel coefficients\>\""}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"AA", "[", 
          RowBox[{"2", ",", "2", ",", "1"}], "]"}], "=", "0"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"AA", "[", 
          RowBox[{"i_", ",", "2", ",", "1"}], "]"}], "=", 
         RowBox[{"AA", "[", 
          RowBox[{"i", ",", "1", ",", "2"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"gamma", "[", 
          RowBox[{"i_", ",", "j_", ",", "k_"}], "]"}], ":=", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"AA", "[", 
             RowBox[{"i", ",", "j", ",", "k"}], "]"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"ee", "*", "gg"}], "-", 
              RowBox[{"ff", "^", "2"}]}], ")"}]}], "/", "2"}], "//", "si"}]}],
         ";", "\[IndentingNewLine]", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"gamma", "[", 
           RowBox[{"i", ",", "j", ",", "k"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "1", ",", "2"}], "}"}]}], "]"}]}]}], " ", 
      RowBox[{"(*", 
       RowBox[{
       "Table", " ", "that", " ", "coefficients", " ", "so", " ", "that", " ",
         "output", " ", "is", " ", "easily", " ", "accessible"}], "*)"}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\n", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Function", " ", "for", " ", "calculating", " ", "Second", " ", 
      "Fundamental", " ", "Form"}], " ", "-", " ", 
     RowBox[{"not", " ", "useful", " ", "yet"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"SecondFF", "[", "x_", "]"}], "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"si", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"Simplify", "[", "#", "]"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"U", "\[Rule]", "u"}], ",", 
             RowBox[{"V", "\[Rule]", "v"}]}], "}"}]}], "&"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"xu", "=", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"x", "[", 
            RowBox[{"U", ",", "V"}], "]"}], ",", "U"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"xv", "=", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"x", "[", 
            RowBox[{"U", ",", "V"}], "]"}], ",", "V"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"ee", "=", 
         RowBox[{
          RowBox[{"xu", ".", "xu"}], "//", "si"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"ff", "=", 
         RowBox[{
          RowBox[{"xu", ".", "xv"}], "//", "si"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"gg", "=", 
         RowBox[{
          RowBox[{"xv", ".", "xv"}], "//", "si"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"eee", "=", 
         RowBox[{"Simplify", "[", 
          FractionBox[
           RowBox[{"Det", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"xu", ",", "U"}], "]"}], ",", "xu", ",", "xv"}], "}"}],
             "]"}], 
           SqrtBox[
            RowBox[{
             RowBox[{"ee", "*", "gg"}], "-", 
             RowBox[{"ff", "*", "ff"}]}]]], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"fff", "=", 
         RowBox[{"Simplify", "[", 
          FractionBox[
           RowBox[{"Det", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"xu", ",", "V"}], "]"}], ",", "xu", ",", "xv"}], "}"}],
             "]"}], 
           SqrtBox[
            RowBox[{
             RowBox[{"ee", "*", "gg"}], "-", 
             RowBox[{"ff", "*", "ff"}]}]]], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"ggg", "=", 
         RowBox[{"Simplify", "[", 
          FractionBox[
           RowBox[{"Det", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"xv", ",", "V"}], "]"}], ",", "xu", ",", "xv"}], "}"}],
             "]"}], 
           SqrtBox[
            RowBox[{
             RowBox[{"ee", "*", "gg"}], "-", 
             RowBox[{"ff", "*", "ff"}]}]]], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"eee1", "=", 
         RowBox[{"eee", "//", "si"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"fff1", "=", 
         RowBox[{"fff", "//", "si"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"ggg1", "=", 
         RowBox[{"ggg", "//", "si"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"eee1", ",", "fff1", ",", "ggg1"}], "}"}]}]}], 
      RowBox[{"(*", 
       RowBox[{"Easy", ",", " ", 
        RowBox[{
        "do", " ", "not", " ", "require", " ", "additional", " ", 
         "explanations"}]}], "*)"}], "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\n", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Function", " ", "that", " ", "solves", " ", "numerically", " ", 
     "equations", " ", "to", " ", "get", " ", "geodesics"}], "*)"}], "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"This", " ", "code", " ", "is", " ", "based", " ", "on", " ", 
      RowBox[{"E", ".", "Abbena"}]}], ",", 
     RowBox[{"S", ".", "Salamon"}], ",", 
     RowBox[{"A", ".", "Gray"}], ",", 
     StyleBox[" ",
      FontSlant->"Italic"], 
     StyleBox[
      RowBox[{
      "Modern", " ", "Differential", " ", "Geometry", " ", "of", " ", 
       "Curves", " ", "and", " ", "Surfaces", " ", "with", " ", 
       "Mathematica"}],
      FontSlant->"Italic"], 
     StyleBox[",",
      FontSlant->"Italic"], 
     StyleBox[" ",
      FontSlant->"Italic"], 
     StyleBox[
      RowBox[{"Third", " ", "Edition"}],
      FontSlant->"Italic"], 
     StyleBox[",",
      FontSlant->"Italic"], 
     StyleBox[" ",
      FontSlant->"Italic"], 
     RowBox[{"Chapman", " ", "and", " ", 
      RowBox[{"Hall", "/", "CRC"}]}], ",", "2006"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"solvegeo", "[", 
      RowBox[{"x_", ",", 
       RowBox[{"{", 
        RowBox[{"u0_", ",", "v0_"}], "}"}], ",", "l_", ",", "m_"}], "]"}], ":=",
      "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"su", ",", "e", ",", "so"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"G", ":=", 
         RowBox[{
          RowBox[{"christoff", "[", "x", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], ";", " ", 
        RowBox[{"(*", 
         RowBox[{"Calculating", " ", "Christoffel", " ", "coefficients"}], 
         "*)"}], "\[IndentingNewLine]", 
        RowBox[{"su", "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"u", "\[Rule]", 
            RowBox[{"u", "[", "s", "]"}]}], ",", 
           RowBox[{"v", "\[Rule]", 
            RowBox[{"v", "[", "s", "]"}]}], ",", 
           RowBox[{"p", "\[Rule]", 
            RowBox[{
             RowBox[{"u", "'"}], "[", "s", "]"}]}], ",", 
           RowBox[{"q", "\[Rule]", 
            RowBox[{
             RowBox[{"v", "'"}], "[", "s", "]"}]}]}], "}"}]}], ";", " ", 
        RowBox[{"(*", "Substitution", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"e", "[", "j_", "]"}], ":=", 
         RowBox[{
          RowBox[{"e", "[", "j", "]"}], "=", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"G", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "1", ",", "1"}], "]"}], "]"}], "*", 
             RowBox[{"p", "^", "2"}]}], "+", 
            RowBox[{"2", "*", 
             RowBox[{"G", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "1", ",", "2"}], "]"}], "]"}], "*", "p", "*",
              "q"}], "+", 
            RowBox[{
             RowBox[{"G", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "2", ",", "2"}], "]"}], "]"}], "*", 
             RowBox[{"q", "^", "2"}]}]}], "/.", "su"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"equic", ":=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"u", "''"}], "[", "s", "]"}], "+", 
             RowBox[{"e", "[", "1", "]"}]}], "\[Equal]", "0"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"v", "''"}], "[", "s", "]"}], "+", 
             RowBox[{"e", "[", "2", "]"}]}], "\[Equal]", "0"}], ",", 
           RowBox[{
            RowBox[{"u", "[", "0", "]"}], "\[Equal]", "u0"}], ",", 
           RowBox[{
            RowBox[{"v", "[", "0", "]"}], "\[Equal]", "v0"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"u", "'"}], "[", "0", "]"}], "\[Equal]", 
            RowBox[{"Cos", "[", "theta", "]"}]}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"v", "'"}], "[", "0", "]"}], "\[Equal]", " ", 
            RowBox[{"Sin", "[", "theta", "]"}]}]}], "}"}]}], ";", " ", 
        RowBox[{"(*", 
         RowBox[{
         "Definition", " ", "of", " ", "the", " ", "equation", " ", "to", " ",
           "be", " ", "solved"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"so", ":=", 
         RowBox[{"NDSolve", "[", 
          RowBox[{"equic", ",", 
           RowBox[{"{", 
            RowBox[{"u", ",", "v"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"s", ",", "0", ",", "l"}], "}"}]}], "]"}]}], ";", " ", 
        RowBox[{"(*", 
         RowBox[{
         "Numerically", " ", "solving", " ", "the", " ", "equations"}], 
         "*)"}], "\[IndentingNewLine]", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"so", ",", 
            RowBox[{"{", 
             RowBox[{"theta", ",", 
              RowBox[{"2", "*", 
               RowBox[{"Pi", "/", "m"}]}], ",", 
              RowBox[{"2", "*", "Pi"}], ",", 
              RowBox[{"2", "*", 
               RowBox[{"Pi", "/", "m"}]}]}], "}"}]}], "]"}], ",", "1"}], 
         "]"}]}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"Table", " ", "the", " ", "results"}], "*)"}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"solvegeoENDP", "[", 
      RowBox[{"x_", ",", 
       RowBox[{"{", 
        RowBox[{"u0_", ",", "v0_"}], "}"}], ",", "l_", ",", "theta_"}], "]"}],
      ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"su", ",", "e", ",", "so"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"G", ":=", 
         RowBox[{
          RowBox[{"christoff", "[", "x", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], ";", " ", 
        RowBox[{"(*", 
         RowBox[{"Calculating", " ", "Christoffel", " ", "coefficients"}], 
         "*)"}], "\[IndentingNewLine]", 
        RowBox[{"su", "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"u", "\[Rule]", 
            RowBox[{"u", "[", "s", "]"}]}], ",", 
           RowBox[{"v", "\[Rule]", 
            RowBox[{"v", "[", "s", "]"}]}], ",", 
           RowBox[{"p", "\[Rule]", 
            RowBox[{
             RowBox[{"u", "'"}], "[", "s", "]"}]}], ",", 
           RowBox[{"q", "\[Rule]", 
            RowBox[{
             RowBox[{"v", "'"}], "[", "s", "]"}]}]}], "}"}]}], ";", " ", 
        RowBox[{"(*", "Substitution", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"e", "[", "j_", "]"}], ":=", 
         RowBox[{
          RowBox[{"e", "[", "j", "]"}], "=", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"G", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "1", ",", "1"}], "]"}], "]"}], "*", 
             RowBox[{"p", "^", "2"}]}], "+", 
            RowBox[{"2", "*", 
             RowBox[{"G", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "1", ",", "2"}], "]"}], "]"}], "*", "p", "*",
              "q"}], "+", 
            RowBox[{
             RowBox[{"G", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "2", ",", "2"}], "]"}], "]"}], "*", 
             RowBox[{"q", "^", "2"}]}]}], "/.", "su"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"equic", ":=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"u", "''"}], "[", "s", "]"}], "+", 
             RowBox[{"e", "[", "1", "]"}]}], "\[Equal]", "0"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"v", "''"}], "[", "s", "]"}], "+", 
             RowBox[{"e", "[", "2", "]"}]}], "\[Equal]", "0"}], ",", 
           RowBox[{
            RowBox[{"u", "[", "0", "]"}], "\[Equal]", "u0"}], ",", 
           RowBox[{
            RowBox[{"v", "[", "0", "]"}], "\[Equal]", "v0"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"u", "'"}], "[", "0", "]"}], "\[Equal]", 
            RowBox[{"Cos", "[", "theta", "]"}]}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"v", "'"}], "[", "0", "]"}], "\[Equal]", " ", 
            RowBox[{"Sin", "[", "theta", "]"}]}]}], "}"}]}], ";", " ", 
        RowBox[{"(*", 
         RowBox[{
         "Definition", " ", "of", " ", "the", " ", "equation", " ", "to", " ",
           "be", " ", "solved"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"NDSolve", "[", 
         RowBox[{"equic", ",", 
          RowBox[{"{", 
           RowBox[{"u", ",", "v"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"s", ",", "0", ",", "l"}], "}"}], ",", 
          RowBox[{"Method", "\[Rule]", "\"\<StiffnessSwitching\>\""}]}], 
         "]"}]}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"Numerically", " ", "solving", " ", "the", " ", "equations"}], 
       "*)"}], "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "The", " ", "main", " ", "function", " ", "used", " ", "for", " ", 
     "Manipulate"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Geodesics", "[", 
     RowBox[{"sh_", ",", 
      RowBox[{"ep_:", "False"}], ",", 
      RowBox[{"{", 
       RowBox[{"u0_", ",", "v0_"}], "}"}], ",", "uk_", ",", "l_", ",", "m_", 
      ",", "a_", ",", "b_", ",", "c_", ",", "Opac_"}], "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"sg", ",", "z0", ",", "z1", ",", "CA"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"CA", "=", "True"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Switch", "[", 
        RowBox[{"sh", ",", 
         RowBox[{"(*", 
          RowBox[{
          "Switch", " ", "to", " ", "select", " ", "the", " ", "chosen", " ", 
           "surface", " ", "and", " ", "appropriate", " ", "bounds", " ", 
           "for", " ", "parametrization"}], "*)"}], "\[IndentingNewLine]", 
         "1", ",", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"x", ":=", "monkeysaddle"}], ",", "\[IndentingNewLine]", 
           RowBox[{"uMin", "=", 
            RowBox[{"-", "1"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"uMax", "=", "1"}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMin", "=", 
            RowBox[{"-", "1"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMax", "=", "1"}]}], "\[IndentingNewLine]", "}"}], ",", 
         "\[IndentingNewLine]", "2", ",", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"x", ":=", 
            RowBox[{"torus", "[", 
             RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"uMin", "=", 
            RowBox[{"-", "Pi"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"uMax", "=", "Pi"}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMin", "=", 
            RowBox[{"-", "Pi"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMax", "=", "Pi"}]}], "\[IndentingNewLine]", "}"}], ",", 
         "\[IndentingNewLine]", "3", ",", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"x", ":=", 
            RowBox[{"helicoid", "[", 
             RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"uMin", "=", "0"}], ",", "\[IndentingNewLine]", 
           RowBox[{"uMax", "=", 
            RowBox[{"2", "*", "Pi"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMin", "=", "0"}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMax", "=", "2"}]}], "\[IndentingNewLine]", "}"}], ",", 
         "\[IndentingNewLine]", "4", ",", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"x", ":=", 
            RowBox[{"exptwist", "[", 
             RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"uMin", "=", 
            RowBox[{"-", "Pi"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"uMax", "=", "1"}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMin", "=", "0"}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMax", "=", "2"}]}], "\[IndentingNewLine]", "}"}], ",", 
         "\[IndentingNewLine]", "5", ",", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"x", ":=", 
            RowBox[{"sphere", "[", "a", "]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"uMin", "=", 
            RowBox[{"-", "Pi"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"uMax", "=", "Pi"}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMin", "=", 
            RowBox[{"-", "Pi"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMax", "=", "Pi"}]}], "\[IndentingNewLine]", "}"}], ",", 
         "\[IndentingNewLine]", "6", ",", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"x", ":=", 
            RowBox[{"paraboloid", "[", 
             RowBox[{"a", ",", "b"}], "]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"uMin", "=", 
            RowBox[{"-", "2"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"uMax", "=", "2"}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMin", "=", 
            RowBox[{"-", "2"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMax", "=", "2"}]}], "\[IndentingNewLine]", "}"}], ",", 
         "\[IndentingNewLine]", "7", ",", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"x", ":=", 
            RowBox[{"elipsoid", "[", 
             RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"uMin", "=", "0"}], ",", "\[IndentingNewLine]", 
           RowBox[{"uMax", "=", 
            RowBox[{"2", "*", "Pi"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMin", "=", "0"}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMax", "=", 
            RowBox[{"2", "*", "Pi"}]}]}], "\[IndentingNewLine]", "}"}], ",", 
         "\[IndentingNewLine]", "8", ",", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"x", ":=", "funnel"}], ",", "\[IndentingNewLine]", 
           RowBox[{"uMin", "=", "0"}], ",", "\[IndentingNewLine]", 
           RowBox[{"uMax", "=", "2"}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMin", "=", "0"}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMax", "=", 
            RowBox[{"2", "*", "Pi"}]}]}], "\[IndentingNewLine]", "}"}], ",", 
         "\[IndentingNewLine]", "9", ",", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"x", ":=", "enneper"}], ",", "\[IndentingNewLine]", 
           RowBox[{"uMin", "=", 
            RowBox[{"-", "Pi"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"uMax", "=", "Pi"}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMin", "=", 
            RowBox[{"-", "Pi"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMax", "=", "Pi"}]}], "\[IndentingNewLine]", "}"}], ",", 
         "\[IndentingNewLine]", "10", ",", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"x", ":=", "klein"}], ",", "\[IndentingNewLine]", 
           RowBox[{"uMin", "=", "0"}], ",", "\[IndentingNewLine]", 
           RowBox[{"uMax", "=", 
            RowBox[{"2", "*", "Pi"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMin", "=", "0"}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMax", "=", 
            RowBox[{"2", "*", "Pi"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"CA", "=", "False"}]}], "\[IndentingNewLine]", "}"}], ",", 
         "\[IndentingNewLine]", "11", ",", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"x", ":=", 
            RowBox[{"moebius", "[", "a", "]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"uMin", "=", 
            RowBox[{"-", "b"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"uMax", "=", "b"}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMin", "=", 
            RowBox[{"-", "Pi"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"vMax", "=", "Pi"}], ","}], "\[IndentingNewLine]", "}"}]}],
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"x0", ":=", 
        RowBox[{"uMin", "+", 
         RowBox[{"u0", "*", 
          RowBox[{"(", 
           RowBox[{"uMax", "-", "uMin"}], ")"}]}]}]}], ";", " ", 
       RowBox[{"(*", 
        RowBox[{
        "Normalization", " ", "of", " ", "the", " ", "chosen", " ", 
         "points"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"y0", ":=", 
        RowBox[{"vMin", "+", 
         RowBox[{"v0", "*", 
          RowBox[{"(", 
           RowBox[{"vMax", "-", "vMin"}], ")"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"xe", ":=", "uk"}], ";", " ", 
       RowBox[{"(*", 
        RowBox[{
        "Normalization", " ", "of", " ", "the", " ", "chosen", " ", 
         "points"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"z0", "=", 
        RowBox[{"ParametricPlot3D", "[", 
         RowBox[{
          RowBox[{"x", "[", 
           RowBox[{"u", ",", "v"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"u", ",", "uMin", ",", "uMax"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"v", ",", "vMin", ",", "vMax"}], "}"}], ",", 
          RowBox[{"Axes", "\[Rule]", "False"}], ",", 
          RowBox[{"Mesh", "\[Rule]", "None"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Opacity", "[", "Opac", "]"}], "}"}]}]}], "]"}]}], ";", 
       RowBox[{"(*", 
        RowBox[{"Plotting", " ", "the", " ", "surface"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"h", "=", 
        RowBox[{"metric", "[", "x", "]"}]}], ";", 
       RowBox[{"(*", 
        RowBox[{
        "Metric", " ", "form", " ", "for", " ", "input", " ", "to", " ", 
         "solving", " ", "geodesics"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{"ep", ",", "\[IndentingNewLine]", 
         RowBox[{"sg", "=", 
          RowBox[{"solvegeoENDP", "[", 
           RowBox[{"h", ",", 
            RowBox[{"{", 
             RowBox[{"x0", ",", "y0"}], "}"}], ",", "l", ",", "uk"}], "]"}]}],
          " ", ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"sg", "=", 
            RowBox[{"solvegeo", "[", 
             RowBox[{"h", ",", 
              RowBox[{"{", 
               RowBox[{"x0", ",", "y0"}], "}"}], ",", "l", ",", "m"}], 
             "]"}]}], " ", ",", "\[IndentingNewLine]", 
           RowBox[{"CA", "=", "False"}]}], "\[IndentingNewLine]", "}"}]}], 
        RowBox[{"(*", 
         RowBox[{"Computing", " ", "geodesics"}], "*)"}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"z1", "=", 
        RowBox[{"ParametricPlot3D", "[", 
         RowBox[{
          RowBox[{"Evaluate", "[", 
           RowBox[{
            RowBox[{"x", "[", 
             RowBox[{
              RowBox[{"u", "[", "t", "]"}], ",", 
              RowBox[{"v", "[", "t", "]"}]}], "]"}], "/.", "sg"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "l"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Thickness", "[", "0.005", "]"}], "}"}]}], ",", 
          RowBox[{"ColorFunction", "\[Rule]", "\"\<DeepSeaColors\>\""}]}], 
         "]"}]}], ";", " ", 
       RowBox[{"(*", 
        RowBox[{"Plotting", " ", "geodesics"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Show", "[", 
        RowBox[{"z0", ",", "z1", ",", " ", 
         RowBox[{"Boxed", "\[Rule]", "False"}], ",", " ", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"500", ",", "500"}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6051394547641935`*^9, 3.605139455615302*^9}, {
  3.6051398113655157`*^9, 3.605139839301067*^9}, {3.6051399384706707`*^9, 
  3.605139970481739*^9}},
 CellID->833127212]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ManipulateSection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Geodesics", "[", 
    RowBox[{"type", ",", "ep", ",", 
     RowBox[{"{", 
      RowBox[{"uz", ",", "vz"}], "}"}], ",", "dir", ",", "inl", ",", "inm", 
     ",", "ina", ",", "inb", ",", "inc", ",", "Opac"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Controls", " ", "-", " ", 
      RowBox[{"selection", " ", "of", " ", "surface"}]}], ",", " ", 
     RowBox[{
     "point", " ", "for", " ", "which", " ", "geodesics", " ", "are", " ", 
      "calculated", " ", "and", " ", "how", " ", "many", " ", "of", " ", 
      "them", " ", "are", " ", "solved"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"type", ",", "1", ",", "\"\<Select surface:\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "\[Rule]", "\"\<Monkey saddle\>\""}], ",", 
       RowBox[{"2", "\[Rule]", "\"\<Torus\>\""}], ",", 
       RowBox[{"3", "\[Rule]", "\"\<Helicoid\>\""}], ",", 
       RowBox[{"4", "\[Rule]", "\"\<Exponential twist\>\""}], ",", 
       RowBox[{"5", "\[Rule]", "\"\<Sphere\>\""}], ",", 
       RowBox[{"6", "\[Rule]", "\"\<Paraboloid\>\""}], ",", 
       RowBox[{"7", "\[Rule]", "\"\<Elipsoid\>\""}], ",", 
       RowBox[{"8", "\[Rule]", "\"\<Funnel surface\>\""}], ",", 
       RowBox[{"9", "->", "\"\<Enneper surface\>\""}], ",", 
       RowBox[{
       "10", "->", "\"\<Klein bottle (Beware! Long calculations)\>\""}], ",", 
       RowBox[{"11", "\[Rule]", "\"\<Moebius strip\>\""}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "PopupMenu"}], ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Top"}]}], "}"}], ",", 
   "\[IndentingNewLine]", "Delimiter", ",", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<Parameters of surface\>\"", ",", "Bold", ",", 
     RowBox[{"RGBColor", "[", 
      RowBox[{".25", ",", ".43", ",", ".82"}], "]"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Parameters", " ", "of", " ", "shape"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ina", ",", "1", ",", "\"\<a\>\""}], "}"}], ",", "0.01", ",", 
     "4", ",", ".01", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}], ",", 
     RowBox[{"Enabled", ":>", 
      RowBox[{"Not", "@", 
       RowBox[{"MemberQ", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "9", ",", "10"}], "}"}], ",", "type"}], 
        "]"}]}]}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"inb", ",", "1", ",", "\"\<b\>\""}], "}"}], ",", "0.01", ",", 
     "4", ",", ".01", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}], ",", 
     RowBox[{"Enabled", "\[RuleDelayed]", 
      RowBox[{"Not", "@", 
       RowBox[{"MemberQ", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "9", ",", "10", ",", "5"}], "}"}], ",", "type"}], 
        "]"}]}]}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"inc", ",", "1", ",", "\"\<c\>\""}], "}"}], ",", "0.01", ",", 
     "4", ",", ".01", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}], ",", 
     RowBox[{"Enabled", "\[RuleDelayed]", 
      RowBox[{"Not", "@", 
       RowBox[{"MemberQ", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "1", ",", "9", ",", "10", ",", "11", ",", "5", ",", "6", ",", "8"}],
           "}"}], ",", "type"}], "]"}]}]}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Opac", ",", "1", ",", "\"\<Opacity\>\""}], "}"}], ",", "0", 
     ",", "1", ",", ".01", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Parameters", " ", "of", " ", "point"}], "*)"}], 
   "\[IndentingNewLine]", "Delimiter", ",", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<Parameters of initial point\>\"", ",", "Bold", ",", 
     RowBox[{"RGBColor", "[", 
      RowBox[{".15", ",", ".57", ",", ".55"}], "]"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"uz", ",", "0.5", ",", "\"\<x0\>\""}], "}"}], ",", "0.01", ",", 
     "0.99", ",", "0.01", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"vz", ",", "0.5", ",", "\"\<y0\>\""}], "}"}], ",", "0.01", ",", 
     "0.99", ",", "0.01", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Parameters", " ", "of", " ", "the", " ", "geodesics"}], "*)"}], 
   "\[IndentingNewLine]", "Delimiter", ",", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<Parameters of geodesics\>\"", ",", "Bold", ",", 
     RowBox[{"RGBColor", "[", 
      RowBox[{".6", ",", ".73", ",", ".36"}], "]"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"inm", ",", "10", ",", "\"\<Number of geodesics:\>\""}], "}"}], 
     ",", "1", ",", "100", ",", "1", ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"Enabled", "\[RuleDelayed]", 
      RowBox[{"!", "ep"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"inl", ",", "1", ",", "\"\<Length:\>\""}], "}"}], ",", "0.01", 
     ",", "30", ",", ".01", ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<OR\>\"", ",", "Bold", ",", 
     RowBox[{"RGBColor", "[", 
      RowBox[{".6", ",", ".73", ",", ".36"}], "]"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<Parameters of direction\>\"", ",", "Bold", ",", 
     RowBox[{"RGBColor", "[", 
      RowBox[{".6", ",", ".73", ",", ".36"}], "]"}]}], "]"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ep", ",", "False", ",", "\"\<Specify direction\>\""}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dir", ",", "0.5", ",", "\"\<Direction:\>\""}], "}"}], ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "+", "0.01"}], ",", 
     RowBox[{"Pi", "-", "0.01"}], ",", "0.01", ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
     RowBox[{"Enabled", "\[RuleDelayed]", "ep"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"ControlPlacement", "\[Rule]", "Left"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AutorunSequencing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ContinuousAction", "\[Rule]", "CA"}]}], "]"}]], "Input",
 CellChangeTimes->{3.605139419507713*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`dir$$ = 
    2.688407346410207, $CellContext`ep$$ = True, $CellContext`ina$$ = 
    1, $CellContext`inb$$ = 1, $CellContext`inc$$ = 1, $CellContext`inl$$ = 
    12.62, $CellContext`inm$$ = 10, $CellContext`Opac$$ = 
    1, $CellContext`type$$ = 8, $CellContext`uz$$ = 0.5, $CellContext`vz$$ = 
    0.5, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`type$$], 1, "Select surface:"}, {
      1 -> "Monkey saddle", 2 -> "Torus", 3 -> "Helicoid", 4 -> 
       "Exponential twist", 5 -> "Sphere", 6 -> "Paraboloid", 7 -> "Elipsoid",
        8 -> "Funnel surface", 9 -> "Enneper surface", 10 -> 
       "Klein bottle (Beware! Long calculations)", 11 -> "Moebius strip"}}, {
      Hold[
       Style["Parameters of surface", Bold, 
        RGBColor[0.25, 0.43, 0.82]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`ina$$], 1, "a"}, 0.01, 4, 0.01}, {{
       Hold[$CellContext`inb$$], 1, "b"}, 0.01, 4, 0.01}, {{
       Hold[$CellContext`inc$$], 1, "c"}, 0.01, 4, 0.01}, {{
       Hold[$CellContext`Opac$$], 1, "Opacity"}, 0, 1, 0.01}, {
      Hold[
       Style["Parameters of initial point", Bold, 
        RGBColor[0.15, 0.57, 0.55]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`uz$$], 0.5, "x0"}, 0.01, 0.99, 0.01}, {{
       Hold[$CellContext`vz$$], 0.5, "y0"}, 0.01, 0.99, 0.01}, {
      Hold[
       Style["Parameters of geodesics", Bold, 
        RGBColor[0.6, 0.73, 0.36]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`inm$$], 10, "Number of geodesics:"}, 1, 100, 1}, {{
       Hold[$CellContext`inl$$], 1, "Length:"}, 0.01, 30, 0.01}, {
      Hold[
       Style["OR", Bold, 
        RGBColor[0.6, 0.73, 0.36]]], Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Style["Parameters of direction", Bold, 
        RGBColor[0.6, 0.73, 0.36]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`ep$$], False, "Specify direction"}, {True, False}}, {{
       Hold[$CellContext`dir$$], 0.5, "Direction:"}, -3.1315926535897933`, 
      3.1315926535897933`, 0.01}}, Typeset`size$$ = {500., {248., 252.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`type$14740$$ = False, $CellContext`ina$14741$$ = 
    0, $CellContext`inb$14742$$ = 0, $CellContext`inc$14743$$ = 
    0, $CellContext`Opac$14744$$ = 0, $CellContext`uz$14745$$ = 
    0, $CellContext`vz$14746$$ = 0, $CellContext`inm$14747$$ = 
    0, $CellContext`inl$14748$$ = 0, $CellContext`ep$14749$$ = 
    False, $CellContext`dir$14750$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`dir$$ = 0.5, $CellContext`ep$$ = 
        False, $CellContext`ina$$ = 1, $CellContext`inb$$ = 
        1, $CellContext`inc$$ = 1, $CellContext`inl$$ = 1, $CellContext`inm$$ = 
        10, $CellContext`Opac$$ = 1, $CellContext`type$$ = 
        1, $CellContext`uz$$ = 0.5, $CellContext`vz$$ = 0.5}, 
      "ControllerVariables" :> {
        Hold[$CellContext`type$$, $CellContext`type$14740$$, False], 
        Hold[$CellContext`ina$$, $CellContext`ina$14741$$, 0], 
        Hold[$CellContext`inb$$, $CellContext`inb$14742$$, 0], 
        Hold[$CellContext`inc$$, $CellContext`inc$14743$$, 0], 
        Hold[$CellContext`Opac$$, $CellContext`Opac$14744$$, 0], 
        Hold[$CellContext`uz$$, $CellContext`uz$14745$$, 0], 
        Hold[$CellContext`vz$$, $CellContext`vz$14746$$, 0], 
        Hold[$CellContext`inm$$, $CellContext`inm$14747$$, 0], 
        Hold[$CellContext`inl$$, $CellContext`inl$14748$$, 0], 
        Hold[$CellContext`ep$$, $CellContext`ep$14749$$, False], 
        Hold[$CellContext`dir$$, $CellContext`dir$14750$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`Geodesics[$CellContext`type$$, \
$CellContext`ep$$, {$CellContext`uz$$, $CellContext`vz$$}, \
$CellContext`dir$$, $CellContext`inl$$, $CellContext`inm$$, \
$CellContext`ina$$, $CellContext`inb$$, $CellContext`inc$$, \
$CellContext`Opac$$], 
      "Specifications" :> {{{$CellContext`type$$, 1, "Select surface:"}, {
         1 -> "Monkey saddle", 2 -> "Torus", 3 -> "Helicoid", 4 -> 
          "Exponential twist", 5 -> "Sphere", 6 -> "Paraboloid", 7 -> 
          "Elipsoid", 8 -> "Funnel surface", 9 -> "Enneper surface", 10 -> 
          "Klein bottle (Beware! Long calculations)", 11 -> "Moebius strip"}, 
         ControlType -> PopupMenu, ControlPlacement -> Top}, Delimiter, 
        Style["Parameters of surface", Bold, 
         RGBColor[0.25, 0.43, 0.82]], {{$CellContext`ina$$, 1, "a"}, 0.01, 4, 
         0.01, Appearance -> "Labeled", ImageSize -> Tiny, Enabled :> Dynamic[
           Not[
            MemberQ[{1, 9, 10}, $CellContext`type$$]]]}, {{$CellContext`inb$$,
           1, "b"}, 0.01, 4, 0.01, Appearance -> "Labeled", ImageSize -> Tiny,
          Enabled :> Dynamic[
           Not[
            
            MemberQ[{1, 9, 10, 
             5}, $CellContext`type$$]]]}, {{$CellContext`inc$$, 1, "c"}, 0.01,
          4, 0.01, Appearance -> "Labeled", ImageSize -> Tiny, Enabled :> 
         Dynamic[
           Not[
            
            MemberQ[{1, 9, 10, 11, 5, 6, 
             8}, $CellContext`type$$]]]}, {{$CellContext`Opac$$, 1, 
          "Opacity"}, 0, 1, 0.01, Appearance -> "Labeled", ImageSize -> Tiny},
         Delimiter, 
        Style["Parameters of initial point", Bold, 
         RGBColor[0.15, 0.57, 0.55]], {{$CellContext`uz$$, 0.5, "x0"}, 0.01, 
         0.99, 0.01, Appearance -> "Labeled", ImageSize -> 
         Tiny}, {{$CellContext`vz$$, 0.5, "y0"}, 0.01, 0.99, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny}, Delimiter, 
        Style["Parameters of geodesics", Bold, 
         RGBColor[
         0.6, 0.73, 0.36]], {{$CellContext`inm$$, 10, "Number of geodesics:"},
          1, 100, 1, ImageSize -> Tiny, Appearance -> "Labeled", Enabled :> 
         Dynamic[
           Not[$CellContext`ep$$]]}, {{$CellContext`inl$$, 1, "Length:"}, 
         0.01, 30, 0.01, ImageSize -> Tiny, Appearance -> "Labeled"}, 
        Style["OR", Bold, 
         RGBColor[0.6, 0.73, 0.36]], 
        Style["Parameters of direction", Bold, 
         RGBColor[
         0.6, 0.73, 0.36]], {{$CellContext`ep$$, False, 
          "Specify direction"}, {
         True, False}}, {{$CellContext`dir$$, 0.5, 
          "Direction:"}, -3.1315926535897933`, 3.1315926535897933`, 0.01, 
         ImageSize -> Tiny, Appearance -> "Labeled", Enabled :> 
         Dynamic[$CellContext`ep$$]}}, 
      "Options" :> {
       ControlPlacement -> Left, AutorunSequencing -> {1, 2}, TrackedSymbols -> 
        True, ContinuousAction -> $CellContext`CA}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{801., {302., 307.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`Geodesics[
         Pattern[$CellContext`sh, 
          Blank[]], 
         Optional[
          Pattern[$CellContext`ep, 
           Blank[]], False], {
          Pattern[$CellContext`u0, 
           Blank[]], 
          Pattern[$CellContext`v0, 
           Blank[]]}, 
         Pattern[$CellContext`uk, 
          Blank[]], 
         Pattern[$CellContext`l, 
          Blank[]], 
         Pattern[$CellContext`m, 
          Blank[]], 
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]], 
         Pattern[$CellContext`Opac, 
          Blank[]]] := 
       Module[{$CellContext`sg, $CellContext`z0, $CellContext`z1, \
$CellContext`CA}, $CellContext`CA = True; 
         Switch[$CellContext`sh, 
           1, {$CellContext`x := $CellContext`monkeysaddle, $CellContext`uMin = \
-1, $CellContext`uMax = 1, $CellContext`vMin = -1, $CellContext`vMax = 1}, 
           2, {$CellContext`x := $CellContext`torus[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = -Pi, $CellContext`uMax = 
            Pi, $CellContext`vMin = -Pi, $CellContext`vMax = Pi}, 
           3, {$CellContext`x := $CellContext`helicoid[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = 0, $CellContext`uMax = 
            2 Pi, $CellContext`vMin = 0, $CellContext`vMax = 2}, 
           4, {$CellContext`x := $CellContext`exptwist[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = -Pi, $CellContext`uMax = 
            1, $CellContext`vMin = 0, $CellContext`vMax = 2}, 
           5, {$CellContext`x := $CellContext`sphere[$CellContext`a], \
$CellContext`uMin = -Pi, $CellContext`uMax = 
            Pi, $CellContext`vMin = -Pi, $CellContext`vMax = Pi}, 
           6, {$CellContext`x := $CellContext`paraboloid[$CellContext`a, \
$CellContext`b], $CellContext`uMin = -2, $CellContext`uMax = 
            2, $CellContext`vMin = -2, $CellContext`vMax = 2}, 
           7, {$CellContext`x := $CellContext`elipsoid[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = 0, $CellContext`uMax = 
            2 Pi, $CellContext`vMin = 0, $CellContext`vMax = 2 Pi}, 
           8, {$CellContext`x := $CellContext`funnel, $CellContext`uMin = 
            0, $CellContext`uMax = 2, $CellContext`vMin = 
            0, $CellContext`vMax = 2 Pi}, 
           9, {$CellContext`x := $CellContext`enneper, $CellContext`uMin = -
             Pi, $CellContext`uMax = 
            Pi, $CellContext`vMin = -Pi, $CellContext`vMax = Pi}, 
           10, {$CellContext`x := $CellContext`klein, $CellContext`uMin = 
            0, $CellContext`uMax = 2 Pi, $CellContext`vMin = 
            0, $CellContext`vMax = 2 Pi, $CellContext`CA = False}, 
           11, {$CellContext`x := $CellContext`moebius[$CellContext`a], \
$CellContext`uMin = -$CellContext`b, $CellContext`uMax = $CellContext`b, \
$CellContext`vMin = -Pi, $CellContext`vMax = Pi, 
            Null}]; $CellContext`x0 := $CellContext`uMin + $CellContext`u0 \
($CellContext`uMax - $CellContext`uMin); $CellContext`y0 := $CellContext`vMin + \
$CellContext`v0 ($CellContext`vMax - $CellContext`vMin); $CellContext`xe := \
$CellContext`uk; $CellContext`z0 = ParametricPlot3D[
            $CellContext`x[$CellContext`u, $CellContext`v], {$CellContext`u, \
$CellContext`uMin, $CellContext`uMax}, {$CellContext`v, $CellContext`vMin, \
$CellContext`vMax}, Axes -> False, Mesh -> None, PlotStyle -> {
              
              Opacity[$CellContext`Opac]}]; $CellContext`h = \
$CellContext`metric[$CellContext`x]; 
         If[$CellContext`ep, $CellContext`sg = \
$CellContext`solvegeoENDP[$CellContext`h, {$CellContext`x0, $CellContext`y0}, \
$CellContext`l, $CellContext`uk], {$CellContext`sg = \
$CellContext`solvegeo[$CellContext`h, {$CellContext`x0, $CellContext`y0}, \
$CellContext`l, $CellContext`m], $CellContext`CA = False}]; $CellContext`z1 = 
          ParametricPlot3D[
            Evaluate[
             ReplaceAll[
              $CellContext`x[
               $CellContext`u[$CellContext`t], 
               $CellContext`v[$CellContext`t]], $CellContext`sg]], \
{$CellContext`t, 0, $CellContext`l}, PlotStyle -> {
              Thickness[0.005]}, ColorFunction -> "DeepSeaColors"]; 
         Show[$CellContext`z0, $CellContext`z1, Boxed -> False, 
           ImageSize -> {500, 500}]], $CellContext`x := $CellContext`torus[
        1, 1.8800000000000001`, 1], $CellContext`torus[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {
        Cos[$CellContext`v] ($CellContext`b + $CellContext`a 
           Cos[$CellContext`u]), 
         Sin[$CellContext`v] ($CellContext`b + $CellContext`a 
           Cos[$CellContext`u]), $CellContext`c 
         Sin[$CellContext`u]}, $CellContext`monkeysaddle[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`u, $CellContext`v, $CellContext`u^3 - 
         3 $CellContext`u $CellContext`v^2}, $CellContext`uMin = -
        Pi, $CellContext`uMax = 
       Pi, $CellContext`vMin = -Pi, $CellContext`vMax = 
       Pi, $CellContext`helicoid[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`a $CellContext`v 
         Cos[$CellContext`u], $CellContext`b $CellContext`v 
         Sin[$CellContext`u], $CellContext`c $CellContext`u}, \
$CellContext`exptwist[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`a $CellContext`v 
         Cos[$CellContext`u], $CellContext`a $CellContext`v 
         Sin[$CellContext`u], $CellContext`a 
         Exp[$CellContext`c $CellContext`u]}, $CellContext`sphere[
         Pattern[$CellContext`a, 
          Blank[]]] := $CellContext`torus[$CellContext`a, 
         0, $CellContext`a], $CellContext`paraboloid[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          
          Blank[]]] := {$CellContext`u, $CellContext`v, $CellContext`a \
$CellContext`u^2 + $CellContext`b $CellContext`v^2}, $CellContext`elipsoid[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`a Sin[$CellContext`u] 
         Cos[$CellContext`v], $CellContext`b Sin[$CellContext`u] 
         Sin[$CellContext`v], $CellContext`c 
         Cos[$CellContext`u]}, $CellContext`funnel[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] = {$CellContext`u Cos[$CellContext`v], $CellContext`u 
         Sin[$CellContext`v], 
         Log[$CellContext`u]}, $CellContext`enneper[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          
          Blank[]]] = {($CellContext`u (1 - $CellContext`u^2/
           3 + $CellContext`v^2))/
         3, -($CellContext`v (1 + $CellContext`u^2 - $CellContext`v^2/3))/
         3, ($CellContext`u^2 - $CellContext`v^2)/3}, $CellContext`klein[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] = {
        Cos[$CellContext`u] (3 + Cos[$CellContext`u/2] Sin[$CellContext`v] - 
          Sin[$CellContext`u/2] Sin[2 $CellContext`v]), 
         Sin[$CellContext`u] (3 + Cos[$CellContext`u/2] Sin[$CellContext`v] - 
          Sin[$CellContext`u/2] Sin[2 $CellContext`v]), 
         Sin[$CellContext`u/2] Sin[$CellContext`v] + 
         Cos[$CellContext`u/2] Sin[2 $CellContext`v]}, $CellContext`moebius[
         Pattern[$CellContext`a, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] = {($CellContext`a + $CellContext`u Cos[$CellContext`v/2])
           Cos[$CellContext`v], ($CellContext`a + $CellContext`u 
           Cos[$CellContext`v/2]) Sin[$CellContext`v], $CellContext`u 
         Sin[$CellContext`v/2]}, $CellContext`x0 := $CellContext`uMin + 
        0.56 ($CellContext`uMax - $CellContext`uMin), $CellContext`y0 := \
$CellContext`vMin + 
        0.86 ($CellContext`vMax - $CellContext`vMin), $CellContext`xe := \
-0.5915926535897933, $CellContext`h = $CellContext`metric[
         $CellContext`torus[1, 1.8800000000000001`, 1]], $CellContext`metric[
         Pattern[$CellContext`x, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := 
       Module[{$CellContext`xu, $CellContext`xv, $CellContext`U, \
$CellContext`V, $CellContext`si}, $CellContext`si = ReplaceAll[
            
            Simplify[#], {$CellContext`U -> $CellContext`u, $CellContext`V -> \
$CellContext`v}]& ; $CellContext`xu = D[
            $CellContext`x[$CellContext`U, $CellContext`V], $CellContext`U]; \
$CellContext`xv = D[
            $CellContext`x[$CellContext`U, $CellContext`V], $CellContext`V]; \
$CellContext`ee = $CellContext`si[
            
            Dot[$CellContext`xu, $CellContext`xu]]; $CellContext`ff = \
$CellContext`si[
            
            Dot[$CellContext`xu, $CellContext`xv]]; $CellContext`gg = \
$CellContext`si[
            
            Dot[$CellContext`xv, $CellContext`xv]]; {{$CellContext`ee, \
$CellContext`ff}, {$CellContext`ff, $CellContext`gg}}], $CellContext`si = 
       ReplaceAll[
         Simplify[#], {$CellContext`U -> $CellContext`u, $CellContext`V -> \
$CellContext`v}]& , $CellContext`ee = 1, $CellContext`ff = 0, $CellContext`gg = 
       3.5344000000000007` + 3.7600000000000002` Cos[$CellContext`U] + 
        Cos[$CellContext`U]^2, $CellContext`solvegeoENDP[
         Pattern[$CellContext`x, 
          Blank[]], {
          Pattern[$CellContext`u0, 
           Blank[]], 
          Pattern[$CellContext`v0, 
           Blank[]]}, 
         Pattern[$CellContext`l, 
          Blank[]], 
         Pattern[$CellContext`theta, 
          Blank[]]] := 
       Module[{$CellContext`su, $CellContext`e, $CellContext`so}, \
$CellContext`G := $CellContext`christoff[$CellContext`x][$CellContext`u, \
$CellContext`v]; $CellContext`su = {$CellContext`u -> \
$CellContext`u[$CellContext`s], $CellContext`v -> \
$CellContext`v[$CellContext`s], $CellContext`p -> 
            Derivative[1][$CellContext`u][$CellContext`s], $CellContext`q -> 
            Derivative[1][$CellContext`v][$CellContext`s]}; $CellContext`e[
            Pattern[$CellContext`j, 
             Blank[]]] := ($CellContext`e[$CellContext`j] = 
           ReplaceAll[
            Part[$CellContext`G, $CellContext`j, 1, 1] $CellContext`p^2 + 
             2 Part[$CellContext`G, $CellContext`j, 1, 
                2] $CellContext`p $CellContext`q + 
             Part[$CellContext`G, $CellContext`j, 2, 
                2] $CellContext`q^2, $CellContext`su]); $CellContext`equic := \
{Derivative[2][$CellContext`u][$CellContext`s] + $CellContext`e[1] == 0, 
            Derivative[2][$CellContext`v][$CellContext`s] + $CellContext`e[2] == 
            0, $CellContext`u[0] == $CellContext`u0, $CellContext`v[
             0] == $CellContext`v0, Derivative[1][$CellContext`u][0] == 
            Cos[$CellContext`theta], Derivative[1][$CellContext`v][0] == 
            Sin[$CellContext`theta]}; 
         NDSolve[$CellContext`equic, {$CellContext`u, $CellContext`v}, \
{$CellContext`s, 0, $CellContext`l}, Method -> 
           "StiffnessSwitching"]], $CellContext`G := $CellContext`christoff[
         $CellContext`metric[
          $CellContext`torus[
          1, 1.8800000000000001`, 
           1]]][$CellContext`u, $CellContext`v], $CellContext`christoff[
         Pattern[$CellContext`M, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := Module[{$CellContext`AA}, $CellContext`si = ReplaceAll[
            
            Simplify[#], {$CellContext`U -> $CellContext`u, $CellContext`V -> \
$CellContext`v}]& ; $CellContext`ee = Part[
            $CellContext`M[$CellContext`U, $CellContext`V], 1, 
            1]; $CellContext`ff = Part[
            $CellContext`M[$CellContext`U, $CellContext`V], 1, 
            2]; $CellContext`gg = Part[
            $CellContext`M[$CellContext`U, $CellContext`V], 2, 
            2]; $CellContext`AA[1, 1, 1] = 
          D[$CellContext`ee, $CellContext`V] $CellContext`ff - 2 
           D[$CellContext`ff, $CellContext`U] $CellContext`ff + 
           D[$CellContext`ee, $CellContext`U] $CellContext`gg; \
$CellContext`AA[2, 2, 2] = 
          D[$CellContext`gg, $CellContext`V] $CellContext`ee - 2 
           D[$CellContext`ff, $CellContext`V] $CellContext`ff + 
           D[$CellContext`gg, $CellContext`U] $CellContext`ff; \
$CellContext`AA[
           2, 1, 1] = (-D[$CellContext`ee, $CellContext`V]) $CellContext`ee + 
           2 D[$CellContext`ff, $CellContext`U] $CellContext`ee - 
           D[$CellContext`ee, $CellContext`U] $CellContext`ff; \
$CellContext`AA[
           1, 2, 2] = (-D[$CellContext`gg, $CellContext`V]) $CellContext`ff + 
           2 D[$CellContext`ff, $CellContext`V] $CellContext`gg - 
           D[$CellContext`gg, $CellContext`U] $CellContext`gg; \
$CellContext`AA[1, 1, 2] = 
          D[$CellContext`ee, $CellContext`V] $CellContext`gg - 
           D[$CellContext`gg, $CellContext`U] $CellContext`ff; \
$CellContext`AA[
           2, 1, 2] = (-D[$CellContext`ee, $CellContext`V]) $CellContext`ff + 
           D[$CellContext`gg, $CellContext`U] $CellContext`ee; \
$CellContext`AA[1, 2, 1] = 0; $CellContext`AA[2, 2, 1] = 0; $CellContext`AA[
            Pattern[$CellContext`i, 
             Blank[]], 2, 1] = $CellContext`AA[$CellContext`i, 1, 
            2]; $CellContext`gamma[
            Pattern[$CellContext`i, 
             Blank[]], 
            Pattern[$CellContext`j, 
             Blank[]], 
            Pattern[$CellContext`k, 
             
             Blank[]]] := $CellContext`si[$CellContext`AA[$CellContext`i, \
$CellContext`j, $CellContext`k] ($CellContext`ee $CellContext`gg - \
$CellContext`ff^2)^(-1)/2]; Table[
           $CellContext`gamma[$CellContext`i, $CellContext`j, \
$CellContext`k], {$CellContext`i, 1, 2}, {$CellContext`j, 1, 
            2}, {$CellContext`k, 1, 2}]], $CellContext`gamma[
         Pattern[$CellContext`i$, 
          Blank[]], 
         Pattern[$CellContext`j$, 
          Blank[]], 
         Pattern[$CellContext`k$, 
          
          Blank[]]] := $CellContext`si[$CellContext`AA$14656[$CellContext`i$, \
$CellContext`j$, $CellContext`k$]/(($CellContext`ee $CellContext`gg - \
$CellContext`ff^2) 2)], Attributes[$CellContext`i$] = {Temporary}, 
       Attributes[$CellContext`j$] = {Temporary}, 
       Attributes[$CellContext`k$] = {Temporary}, 
       Attributes[$CellContext`AA$14656] = {Temporary}, $CellContext`AA$14656[
        1, 1, 1] = 0, $CellContext`AA$14656[1, 1, 2] = 
       0, $CellContext`AA$14656[1, 2, 1] = 
       0, $CellContext`AA$14656[
        1, 2, 2] = -((3.5344000000000007` + 
          3.7600000000000002` Cos[$CellContext`U] + 
          Cos[$CellContext`U]^2) ((-3.7600000000000002`) Sin[$CellContext`U] - 
          2 Cos[$CellContext`U] Sin[$CellContext`U])), $CellContext`AA$14656[
        2, 1, 1] = 
       0, $CellContext`AA$14656[
        2, 1, 2] = (-3.7600000000000002`) Sin[$CellContext`U] - 2 
        Cos[$CellContext`U] Sin[$CellContext`U], $CellContext`AA$14656[
        2, 2, 1] = 0, $CellContext`AA$14656[2, 2, 2] = 
       0, $CellContext`AA$14656[
         Pattern[$CellContext`i$, 
          Blank[]], 2, 1] = $CellContext`AA$14656[$CellContext`i$, 1, 2], 
       Attributes[Derivative] = {
        NHoldAll, ReadProtected}, $CellContext`equic := {
        Derivative[2][$CellContext`u][$CellContext`s] + $CellContext`e$14635[
           1] == 0, 
         Derivative[2][$CellContext`v][$CellContext`s] + $CellContext`e$14635[
           2] == 0, $CellContext`u[0] == 
         0.3769911184307757, $CellContext`v[0] == 2.2619467105846507`, 
         Derivative[1][$CellContext`u][0] == Cos[-0.5915926535897933], 
         Derivative[1][$CellContext`v][0] == Sin[-0.5915926535897933]}, 
       Attributes[$CellContext`e$14635] = {Temporary}, $CellContext`e$14635[
        1] = (1.8800000000000001` + Cos[
           $CellContext`u[$CellContext`s]]) Sin[
          $CellContext`u[$CellContext`s]] 
        Derivative[1][$CellContext`v][$CellContext`s]^2, $CellContext`e$14635[
        2] = (2 (-1.8800000000000001` - 1. Cos[
            $CellContext`u[$CellContext`s]]) Sin[
           $CellContext`u[$CellContext`s]] 
         Derivative[1][$CellContext`u][$CellContext`s] 
         Derivative[1][$CellContext`v][$CellContext`s])/(3.5344000000000007` + 
        3.7600000000000002` Cos[
           $CellContext`u[$CellContext`s]] + Cos[
           $CellContext`u[$CellContext`s]]^2), $CellContext`e$14635[
         Pattern[$CellContext`j$, 
          Blank[]]] := ($CellContext`e$14635[$CellContext`j$] = 
        ReplaceAll[
         Part[$CellContext`G, $CellContext`j$, 1, 1] $CellContext`p^2 + 
          2 Part[$CellContext`G, $CellContext`j$, 1, 
             2] $CellContext`p $CellContext`q + 
          Part[$CellContext`G, $CellContext`j$, 2, 
             2] $CellContext`q^2, $CellContext`su$14635]), 
       Attributes[$CellContext`su$14635] = {
        Temporary}, $CellContext`su$14635 = {$CellContext`u -> \
$CellContext`u[$CellContext`s], $CellContext`v -> \
$CellContext`v[$CellContext`s], $CellContext`p -> 
         Derivative[1][$CellContext`u][$CellContext`s], $CellContext`q -> 
         Derivative[1][$CellContext`v][$CellContext`s]}, $CellContext`solvegeo[
         Pattern[$CellContext`x, 
          Blank[]], {
          Pattern[$CellContext`u0, 
           Blank[]], 
          Pattern[$CellContext`v0, 
           Blank[]]}, 
         Pattern[$CellContext`l, 
          Blank[]], 
         Pattern[$CellContext`m, 
          Blank[]]] := 
       Module[{$CellContext`su, $CellContext`e, $CellContext`so}, \
$CellContext`G := $CellContext`christoff[$CellContext`x][$CellContext`u, \
$CellContext`v]; $CellContext`su = {$CellContext`u -> \
$CellContext`u[$CellContext`s], $CellContext`v -> \
$CellContext`v[$CellContext`s], $CellContext`p -> 
            Derivative[1][$CellContext`u][$CellContext`s], $CellContext`q -> 
            Derivative[1][$CellContext`v][$CellContext`s]}; $CellContext`e[
            Pattern[$CellContext`j, 
             Blank[]]] := ($CellContext`e[$CellContext`j] = 
           ReplaceAll[
            Part[$CellContext`G, $CellContext`j, 1, 1] $CellContext`p^2 + 
             2 Part[$CellContext`G, $CellContext`j, 1, 
                2] $CellContext`p $CellContext`q + 
             Part[$CellContext`G, $CellContext`j, 2, 
                2] $CellContext`q^2, $CellContext`su]); $CellContext`equic := \
{Derivative[2][$CellContext`u][$CellContext`s] + $CellContext`e[1] == 0, 
            Derivative[2][$CellContext`v][$CellContext`s] + $CellContext`e[2] == 
            0, $CellContext`u[0] == $CellContext`u0, $CellContext`v[
             0] == $CellContext`v0, Derivative[1][$CellContext`u][0] == 
            Cos[$CellContext`theta], Derivative[1][$CellContext`v][0] == 
            Sin[$CellContext`theta]}; $CellContext`so := 
          NDSolve[$CellContext`equic, {$CellContext`u, $CellContext`v}, \
{$CellContext`s, 0, $CellContext`l}]; Flatten[
           
           Table[$CellContext`so, {$CellContext`theta, 2 (Pi/$CellContext`m), 
             2 Pi, 2 (Pi/$CellContext`m)}], 1]]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6051395801311274`*^9, {3.6051398434445934`*^9, 3.605139856819293*^9}, 
   3.605140049321759*^9},
 CellID->110791267]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ManipulateCaptionSection"],

Cell[TextData[StyleBox["I present geodesics curves on some selected surfaces. \
NDSolve is used for solving appropriate differential equation and define \
functions for calculation Christoffel coefficients and second fundamental \
form (that is actually not needed, but I included that just for possible \
extentions for asymptotic curves). Also, there are some surfaces for user' s \
choice - the program is easily extendable for other surfaces.", "Text",
 FontWeight->"Plain"]], "ManipulateCaption",
 CellChangeTimes->{
  3.6051395111923656`*^9, {3.60514026688341*^9, 3.6051402718980474`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ThumbnailSection"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`dir$$ = 0.5, $CellContext`ep$$ = 
    False, $CellContext`ina$$ = 1, $CellContext`inb$$ = 
    1, $CellContext`inc$$ = 1, $CellContext`inl$$ = 1, $CellContext`inm$$ = 
    10, $CellContext`Opac$$ = 1, $CellContext`type$$ = 1, $CellContext`uz$$ = 
    0.5, $CellContext`vz$$ = 0.5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`type$$], 1, "Select surface:"}, {
      1 -> "Monkey saddle", 2 -> "Torus", 3 -> "Helicoid", 4 -> 
       "Exponential twist", 5 -> "Sphere", 6 -> "Paraboloid", 7 -> "Elipsoid",
        8 -> "Funnel surface", 9 -> "Enneper surface", 10 -> 
       "Klein bottle (Beware! Long calculations)", 11 -> "Moebius strip"}}, {
      Hold[
       Style["Parameters of surface", Bold, 
        RGBColor[0.25, 0.43, 0.82]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`ina$$], 1, "a"}, 0.01, 4, 0.01}, {{
       Hold[$CellContext`inb$$], 1, "b"}, 0.01, 4, 0.01}, {{
       Hold[$CellContext`inc$$], 1, "c"}, 0.01, 4, 0.01}, {{
       Hold[$CellContext`Opac$$], 1, "Opacity"}, 0, 1, 0.01}, {
      Hold[
       Style["Parameters of initial point", Bold, 
        RGBColor[0.15, 0.57, 0.55]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`uz$$], 0.5, "x0"}, 0.01, 0.99, 0.01}, {{
       Hold[$CellContext`vz$$], 0.5, "y0"}, 0.01, 0.99, 0.01}, {
      Hold[
       Style["Parameters of geodesics", Bold, 
        RGBColor[0.6, 0.73, 0.36]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`inm$$], 10, "Number of geodesics:"}, 1, 100, 1}, {{
       Hold[$CellContext`inl$$], 1, "Length:"}, 0.01, 30, 0.01}, {
      Hold[
       Style["OR", Bold, 
        RGBColor[0.6, 0.73, 0.36]]], Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Style["Parameters of direction", Bold, 
        RGBColor[0.6, 0.73, 0.36]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`ep$$], False, "Specify direction"}, {True, False}}, {{
       Hold[$CellContext`dir$$], 0.5, "Direction:"}, -3.1315926535897933`, 
      3.1315926535897933`, 0.01}}, Typeset`size$$ = {500., {248., 252.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`type$3016$$ = False, $CellContext`ina$3017$$ = 
    0, $CellContext`inb$3018$$ = 0, $CellContext`inc$3019$$ = 
    0, $CellContext`Opac$3020$$ = 0, $CellContext`uz$3021$$ = 
    0, $CellContext`vz$3022$$ = 0, $CellContext`inm$3023$$ = 
    0, $CellContext`inl$3024$$ = 0, $CellContext`ep$3025$$ = 
    False, $CellContext`dir$3026$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`dir$$ = 0.5, $CellContext`ep$$ = 
        False, $CellContext`ina$$ = 1, $CellContext`inb$$ = 
        1, $CellContext`inc$$ = 1, $CellContext`inl$$ = 1, $CellContext`inm$$ = 
        10, $CellContext`Opac$$ = 1, $CellContext`type$$ = 
        1, $CellContext`uz$$ = 0.5, $CellContext`vz$$ = 0.5}, 
      "ControllerVariables" :> {
        Hold[$CellContext`type$$, $CellContext`type$3016$$, False], 
        Hold[$CellContext`ina$$, $CellContext`ina$3017$$, 0], 
        Hold[$CellContext`inb$$, $CellContext`inb$3018$$, 0], 
        Hold[$CellContext`inc$$, $CellContext`inc$3019$$, 0], 
        Hold[$CellContext`Opac$$, $CellContext`Opac$3020$$, 0], 
        Hold[$CellContext`uz$$, $CellContext`uz$3021$$, 0], 
        Hold[$CellContext`vz$$, $CellContext`vz$3022$$, 0], 
        Hold[$CellContext`inm$$, $CellContext`inm$3023$$, 0], 
        Hold[$CellContext`inl$$, $CellContext`inl$3024$$, 0], 
        Hold[$CellContext`ep$$, $CellContext`ep$3025$$, False], 
        Hold[$CellContext`dir$$, $CellContext`dir$3026$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`Geodesics[$CellContext`type$$, \
$CellContext`ep$$, {$CellContext`uz$$, $CellContext`vz$$}, \
$CellContext`dir$$, $CellContext`inl$$, $CellContext`inm$$, \
$CellContext`ina$$, $CellContext`inb$$, $CellContext`inc$$, \
$CellContext`Opac$$], 
      "Specifications" :> {{{$CellContext`type$$, 1, "Select surface:"}, {
         1 -> "Monkey saddle", 2 -> "Torus", 3 -> "Helicoid", 4 -> 
          "Exponential twist", 5 -> "Sphere", 6 -> "Paraboloid", 7 -> 
          "Elipsoid", 8 -> "Funnel surface", 9 -> "Enneper surface", 10 -> 
          "Klein bottle (Beware! Long calculations)", 11 -> "Moebius strip"}, 
         ControlType -> PopupMenu, ControlPlacement -> Top}, Delimiter, 
        Style["Parameters of surface", Bold, 
         RGBColor[0.25, 0.43, 0.82]], {{$CellContext`ina$$, 1, "a"}, 0.01, 4, 
         0.01, Appearance -> "Labeled", ImageSize -> Tiny, Enabled :> Dynamic[
           Not[
            MemberQ[{1, 9, 10}, $CellContext`type$$]]]}, {{$CellContext`inb$$,
           1, "b"}, 0.01, 4, 0.01, Appearance -> "Labeled", ImageSize -> Tiny,
          Enabled :> Dynamic[
           Not[
            
            MemberQ[{1, 9, 10, 
             5}, $CellContext`type$$]]]}, {{$CellContext`inc$$, 1, "c"}, 0.01,
          4, 0.01, Appearance -> "Labeled", ImageSize -> Tiny, Enabled :> 
         Dynamic[
           Not[
            
            MemberQ[{1, 9, 10, 11, 5, 6, 
             8}, $CellContext`type$$]]]}, {{$CellContext`Opac$$, 1, 
          "Opacity"}, 0, 1, 0.01, Appearance -> "Labeled", ImageSize -> Tiny},
         Delimiter, 
        Style["Parameters of initial point", Bold, 
         RGBColor[0.15, 0.57, 0.55]], {{$CellContext`uz$$, 0.5, "x0"}, 0.01, 
         0.99, 0.01, Appearance -> "Labeled", ImageSize -> 
         Tiny}, {{$CellContext`vz$$, 0.5, "y0"}, 0.01, 0.99, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny}, Delimiter, 
        Style["Parameters of geodesics", Bold, 
         RGBColor[
         0.6, 0.73, 0.36]], {{$CellContext`inm$$, 10, "Number of geodesics:"},
          1, 100, 1, ImageSize -> Tiny, Appearance -> "Labeled", Enabled :> 
         Dynamic[
           Not[$CellContext`ep$$]]}, {{$CellContext`inl$$, 1, "Length:"}, 
         0.01, 30, 0.01, ImageSize -> Tiny, Appearance -> "Labeled"}, 
        Style["OR", Bold, 
         RGBColor[0.6, 0.73, 0.36]], 
        Style["Parameters of direction", Bold, 
         RGBColor[
         0.6, 0.73, 0.36]], {{$CellContext`ep$$, False, 
          "Specify direction"}, {
         True, False}}, {{$CellContext`dir$$, 0.5, 
          "Direction:"}, -3.1315926535897933`, 3.1315926535897933`, 0.01, 
         ImageSize -> Tiny, Appearance -> "Labeled", Enabled :> 
         Dynamic[$CellContext`ep$$]}}, 
      "Options" :> {
       ControlPlacement -> Left, AutorunSequencing -> {1, 2}, TrackedSymbols -> 
        True, ContinuousAction -> $CellContext`CA}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{801., {302., 307.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`Geodesics[
         Pattern[$CellContext`sh, 
          Blank[]], 
         Optional[
          Pattern[$CellContext`ep, 
           Blank[]], False], {
          Pattern[$CellContext`u0, 
           Blank[]], 
          Pattern[$CellContext`v0, 
           Blank[]]}, 
         Pattern[$CellContext`uk, 
          Blank[]], 
         Pattern[$CellContext`l, 
          Blank[]], 
         Pattern[$CellContext`m, 
          Blank[]], 
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]], 
         Pattern[$CellContext`Opac, 
          Blank[]]] := 
       Module[{$CellContext`sg, $CellContext`z0, $CellContext`z1, \
$CellContext`CA}, $CellContext`CA = True; 
         Switch[$CellContext`sh, 
           1, {$CellContext`x := $CellContext`monkeysaddle, $CellContext`uMin = \
-1, $CellContext`uMax = 1, $CellContext`vMin = -1, $CellContext`vMax = 1}, 
           2, {$CellContext`x := $CellContext`torus[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = -Pi, $CellContext`uMax = 
            Pi, $CellContext`vMin = -Pi, $CellContext`vMax = Pi}, 
           3, {$CellContext`x := $CellContext`helicoid[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = 0, $CellContext`uMax = 
            2 Pi, $CellContext`vMin = 0, $CellContext`vMax = 2}, 
           4, {$CellContext`x := $CellContext`exptwist[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = -Pi, $CellContext`uMax = 
            1, $CellContext`vMin = 0, $CellContext`vMax = 2}, 
           5, {$CellContext`x := $CellContext`sphere[$CellContext`a], \
$CellContext`uMin = -Pi, $CellContext`uMax = 
            Pi, $CellContext`vMin = -Pi, $CellContext`vMax = Pi}, 
           6, {$CellContext`x := $CellContext`paraboloid[$CellContext`a, \
$CellContext`b], $CellContext`uMin = -2, $CellContext`uMax = 
            2, $CellContext`vMin = -2, $CellContext`vMax = 2}, 
           7, {$CellContext`x := $CellContext`elipsoid[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = 0, $CellContext`uMax = 
            2 Pi, $CellContext`vMin = 0, $CellContext`vMax = 2 Pi}, 
           8, {$CellContext`x := $CellContext`funnel, $CellContext`uMin = 
            0, $CellContext`uMax = 2, $CellContext`vMin = 
            0, $CellContext`vMax = 2 Pi}, 
           9, {$CellContext`x := $CellContext`enneper, $CellContext`uMin = -
             Pi, $CellContext`uMax = 
            Pi, $CellContext`vMin = -Pi, $CellContext`vMax = Pi}, 
           10, {$CellContext`x := $CellContext`klein, $CellContext`uMin = 
            0, $CellContext`uMax = 2 Pi, $CellContext`vMin = 
            0, $CellContext`vMax = 2 Pi, $CellContext`CA = False}, 
           11, {$CellContext`x := $CellContext`moebius[$CellContext`a], \
$CellContext`uMin = -$CellContext`b, $CellContext`uMax = $CellContext`b, \
$CellContext`vMin = -Pi, $CellContext`vMax = Pi, 
            Null}]; $CellContext`x0 := $CellContext`uMin + $CellContext`u0 \
($CellContext`uMax - $CellContext`uMin); $CellContext`y0 := $CellContext`vMin + \
$CellContext`v0 ($CellContext`vMax - $CellContext`vMin); $CellContext`xe := \
$CellContext`uk; $CellContext`z0 = ParametricPlot3D[
            $CellContext`x[$CellContext`u, $CellContext`v], {$CellContext`u, \
$CellContext`uMin, $CellContext`uMax}, {$CellContext`v, $CellContext`vMin, \
$CellContext`vMax}, Axes -> False, Mesh -> None, PlotStyle -> {
              
              Opacity[$CellContext`Opac]}]; $CellContext`h = \
$CellContext`metric[$CellContext`x]; 
         If[$CellContext`ep, $CellContext`sg = \
$CellContext`solvegeoENDP[$CellContext`h, {$CellContext`x0, $CellContext`y0}, \
$CellContext`l, $CellContext`uk], {$CellContext`sg = \
$CellContext`solvegeo[$CellContext`h, {$CellContext`x0, $CellContext`y0}, \
$CellContext`l, $CellContext`m], $CellContext`CA = False}]; $CellContext`z1 = 
          ParametricPlot3D[
            Evaluate[
             ReplaceAll[
              $CellContext`x[
               $CellContext`u[$CellContext`t], 
               $CellContext`v[$CellContext`t]], $CellContext`sg]], \
{$CellContext`t, 0, $CellContext`l}, PlotStyle -> {
              Thickness[0.005]}, ColorFunction -> "DeepSeaColors"]; 
         Show[$CellContext`z0, $CellContext`z1, Boxed -> False, 
           ImageSize -> {500, 500}]], $CellContext`monkeysaddle[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`u, $CellContext`v, $CellContext`u^3 - 
         3 $CellContext`u $CellContext`v^2}, $CellContext`torus[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {
        Cos[$CellContext`v] ($CellContext`b + $CellContext`a 
           Cos[$CellContext`u]), 
         Sin[$CellContext`v] ($CellContext`b + $CellContext`a 
           Cos[$CellContext`u]), $CellContext`c 
         Sin[$CellContext`u]}, $CellContext`helicoid[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`a $CellContext`v 
         Cos[$CellContext`u], $CellContext`b $CellContext`v 
         Sin[$CellContext`u], $CellContext`c $CellContext`u}, \
$CellContext`exptwist[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`a $CellContext`v 
         Cos[$CellContext`u], $CellContext`a $CellContext`v 
         Sin[$CellContext`u], $CellContext`a 
         Exp[$CellContext`c $CellContext`u]}, $CellContext`sphere[
         Pattern[$CellContext`a, 
          Blank[]]] := $CellContext`torus[$CellContext`a, 
         0, $CellContext`a], $CellContext`paraboloid[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          
          Blank[]]] := {$CellContext`u, $CellContext`v, $CellContext`a \
$CellContext`u^2 + $CellContext`b $CellContext`v^2}, $CellContext`elipsoid[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`a Sin[$CellContext`u] 
         Cos[$CellContext`v], $CellContext`b Sin[$CellContext`u] 
         Sin[$CellContext`v], $CellContext`c 
         Cos[$CellContext`u]}, $CellContext`funnel[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] = {$CellContext`u Cos[$CellContext`v], $CellContext`u 
         Sin[$CellContext`v], 
         Log[$CellContext`u]}, $CellContext`enneper[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          
          Blank[]]] = {($CellContext`u (1 - $CellContext`u^2/
           3 + $CellContext`v^2))/
         3, -($CellContext`v (1 + $CellContext`u^2 - $CellContext`v^2/3))/
         3, ($CellContext`u^2 - $CellContext`v^2)/3}, $CellContext`klein[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] = {
        Cos[$CellContext`u] (3 + Cos[$CellContext`u/2] Sin[$CellContext`v] - 
          Sin[$CellContext`u/2] Sin[2 $CellContext`v]), 
         Sin[$CellContext`u] (3 + Cos[$CellContext`u/2] Sin[$CellContext`v] - 
          Sin[$CellContext`u/2] Sin[2 $CellContext`v]), 
         Sin[$CellContext`u/2] Sin[$CellContext`v] + 
         Cos[$CellContext`u/2] Sin[2 $CellContext`v]}, $CellContext`moebius[
         Pattern[$CellContext`a, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] = {($CellContext`a + $CellContext`u Cos[$CellContext`v/2])
           Cos[$CellContext`v], ($CellContext`a + $CellContext`u 
           Cos[$CellContext`v/2]) Sin[$CellContext`v], $CellContext`u 
         Sin[$CellContext`v/2]}, $CellContext`metric[
         Pattern[$CellContext`x, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := 
       Module[{$CellContext`xu, $CellContext`xv, $CellContext`U, \
$CellContext`V, $CellContext`si}, $CellContext`si = ReplaceAll[
            
            Simplify[#], {$CellContext`U -> $CellContext`u, $CellContext`V -> \
$CellContext`v}]& ; $CellContext`xu = D[
            $CellContext`x[$CellContext`U, $CellContext`V], $CellContext`U]; \
$CellContext`xv = D[
            $CellContext`x[$CellContext`U, $CellContext`V], $CellContext`V]; \
$CellContext`ee = $CellContext`si[
            
            Dot[$CellContext`xu, $CellContext`xu]]; $CellContext`ff = \
$CellContext`si[
            
            Dot[$CellContext`xu, $CellContext`xv]]; $CellContext`gg = \
$CellContext`si[
            
            Dot[$CellContext`xv, $CellContext`xv]]; {{$CellContext`ee, \
$CellContext`ff}, {$CellContext`ff, $CellContext`gg}}], \
$CellContext`solvegeoENDP[
         Pattern[$CellContext`x, 
          Blank[]], {
          Pattern[$CellContext`u0, 
           Blank[]], 
          Pattern[$CellContext`v0, 
           Blank[]]}, 
         Pattern[$CellContext`l, 
          Blank[]], 
         Pattern[$CellContext`theta, 
          Blank[]]] := 
       Module[{$CellContext`su, $CellContext`e, $CellContext`so}, \
$CellContext`G := $CellContext`christoff[$CellContext`x][$CellContext`u, \
$CellContext`v]; $CellContext`su = {$CellContext`u -> \
$CellContext`u[$CellContext`s], $CellContext`v -> \
$CellContext`v[$CellContext`s], $CellContext`p -> 
            Derivative[1][$CellContext`u][$CellContext`s], $CellContext`q -> 
            Derivative[1][$CellContext`v][$CellContext`s]}; $CellContext`e[
            Pattern[$CellContext`j, 
             Blank[]]] := ($CellContext`e[$CellContext`j] = 
           ReplaceAll[
            Part[$CellContext`G, $CellContext`j, 1, 1] $CellContext`p^2 + 
             2 Part[$CellContext`G, $CellContext`j, 1, 
                2] $CellContext`p $CellContext`q + 
             Part[$CellContext`G, $CellContext`j, 2, 
                2] $CellContext`q^2, $CellContext`su]); $CellContext`equic := \
{Derivative[2][$CellContext`u][$CellContext`s] + $CellContext`e[1] == 0, 
            Derivative[2][$CellContext`v][$CellContext`s] + $CellContext`e[2] == 
            0, $CellContext`u[0] == $CellContext`u0, $CellContext`v[
             0] == $CellContext`v0, Derivative[1][$CellContext`u][0] == 
            Cos[$CellContext`theta], Derivative[1][$CellContext`v][0] == 
            Sin[$CellContext`theta]}; 
         NDSolve[$CellContext`equic, {$CellContext`u, $CellContext`v}, \
{$CellContext`s, 0, $CellContext`l}, Method -> 
           "StiffnessSwitching"]], $CellContext`christoff[
         Pattern[$CellContext`M, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := Module[{$CellContext`A}, $CellContext`si = ReplaceAll[
            
            Simplify[#], {$CellContext`U -> $CellContext`u, $CellContext`V -> \
$CellContext`v}]& ; $CellContext`ee = Part[
            $CellContext`M[$CellContext`U, $CellContext`V], 1, 
            1]; $CellContext`ff = Part[
            $CellContext`M[$CellContext`U, $CellContext`V], 1, 
            2]; $CellContext`gg = Part[
            $CellContext`M[$CellContext`U, $CellContext`V], 2, 
            2]; $CellContext`A[1, 1, 1] = 
          D[$CellContext`ee, $CellContext`V] $CellContext`ff - 2 
           D[$CellContext`ff, $CellContext`U] $CellContext`ff + 
           D[$CellContext`ee, $CellContext`U] $CellContext`gg; $CellContext`A[
           2, 2, 2] = 
          D[$CellContext`gg, $CellContext`V] $CellContext`ee - 2 
           D[$CellContext`ff, $CellContext`V] $CellContext`ff + 
           D[$CellContext`gg, $CellContext`U] $CellContext`ff; $CellContext`A[
           2, 1, 1] = (-D[$CellContext`ee, $CellContext`V]) $CellContext`ee + 
           2 D[$CellContext`ff, $CellContext`U] $CellContext`ee - 
           D[$CellContext`ee, $CellContext`U] $CellContext`ff; $CellContext`A[
           1, 2, 2] = (-D[$CellContext`gg, $CellContext`V]) $CellContext`ff + 
           2 D[$CellContext`ff, $CellContext`V] $CellContext`gg - 
           D[$CellContext`gg, $CellContext`U] $CellContext`gg; $CellContext`A[
           1, 1, 2] = 
          D[$CellContext`ee, $CellContext`V] $CellContext`gg - 
           D[$CellContext`gg, $CellContext`U] $CellContext`ff; $CellContext`A[
           2, 1, 2] = (-D[$CellContext`ee, $CellContext`V]) $CellContext`ff + 
           D[$CellContext`gg, $CellContext`U] $CellContext`ee; $CellContext`A[
           1, 2, 1] = 0; $CellContext`A[2, 2, 1] = 0; $CellContext`A[
            Pattern[$CellContext`i, 
             Blank[]], 2, 1] = $CellContext`A[$CellContext`i, 1, 
            2]; $CellContext`gamma[
            Pattern[$CellContext`i, 
             Blank[]], 
            Pattern[$CellContext`j, 
             Blank[]], 
            Pattern[$CellContext`k, 
             
             Blank[]]] := $CellContext`si[$CellContext`A[$CellContext`i, \
$CellContext`j, $CellContext`k] ($CellContext`ee $CellContext`gg - \
$CellContext`ff^2)^(-1)/2]; Table[
           $CellContext`gamma[$CellContext`i, $CellContext`j, \
$CellContext`k], {$CellContext`i, 1, 2}, {$CellContext`j, 1, 
            2}, {$CellContext`k, 1, 2}]], 
       Attributes[Derivative] = {
        NHoldAll, ReadProtected}, $CellContext`solvegeo[
         Pattern[$CellContext`x, 
          Blank[]], {
          Pattern[$CellContext`u0, 
           Blank[]], 
          Pattern[$CellContext`v0, 
           Blank[]]}, 
         Pattern[$CellContext`l, 
          Blank[]], 
         Pattern[$CellContext`m, 
          Blank[]]] := 
       Module[{$CellContext`su, $CellContext`e, $CellContext`so}, \
$CellContext`G := $CellContext`christoff[$CellContext`x][$CellContext`u, \
$CellContext`v]; $CellContext`su = {$CellContext`u -> \
$CellContext`u[$CellContext`s], $CellContext`v -> \
$CellContext`v[$CellContext`s], $CellContext`p -> 
            Derivative[1][$CellContext`u][$CellContext`s], $CellContext`q -> 
            Derivative[1][$CellContext`v][$CellContext`s]}; $CellContext`e[
            Pattern[$CellContext`j, 
             Blank[]]] := ($CellContext`e[$CellContext`j] = 
           ReplaceAll[
            Part[$CellContext`G, $CellContext`j, 1, 1] $CellContext`p^2 + 
             2 Part[$CellContext`G, $CellContext`j, 1, 
                2] $CellContext`p $CellContext`q + 
             Part[$CellContext`G, $CellContext`j, 2, 
                2] $CellContext`q^2, $CellContext`su]); $CellContext`equic := \
{Derivative[2][$CellContext`u][$CellContext`s] + $CellContext`e[1] == 0, 
            Derivative[2][$CellContext`v][$CellContext`s] + $CellContext`e[2] == 
            0, $CellContext`u[0] == $CellContext`u0, $CellContext`v[
             0] == $CellContext`v0, Derivative[1][$CellContext`u][0] == 
            Cos[$CellContext`theta], Derivative[1][$CellContext`v][0] == 
            Sin[$CellContext`theta]}; $CellContext`so := 
          NDSolve[$CellContext`equic, {$CellContext`u, $CellContext`v}, \
{$CellContext`s, 0, $CellContext`l}]; Flatten[
           
           Table[$CellContext`so, {$CellContext`theta, 2 (Pi/$CellContext`m), 
             2 Pi, 2 (Pi/$CellContext`m)}], 1]]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellEditDuplicate->False,
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.605139594149909*^9, 3.6051395946829777`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SnapshotsSection"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`dir$$ = 0.5, $CellContext`ep$$ = 
    False, $CellContext`ina$$ = 1, $CellContext`inb$$ = 
    1, $CellContext`inc$$ = 1, $CellContext`inl$$ = 1, $CellContext`inm$$ = 
    10, $CellContext`Opac$$ = 1, $CellContext`type$$ = 1, $CellContext`uz$$ = 
    0.5, $CellContext`vz$$ = 0.5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`type$$], 1, "Select surface:"}, {
      1 -> "Monkey saddle", 2 -> "Torus", 3 -> "Helicoid", 4 -> 
       "Exponential twist", 5 -> "Sphere", 6 -> "Paraboloid", 7 -> "Elipsoid",
        8 -> "Funnel surface", 9 -> "Enneper surface", 10 -> 
       "Klein bottle (Beware! Long calculations)", 11 -> "Moebius strip"}}, {
      Hold[
       Style["Parameters of surface", Bold, 
        RGBColor[0.25, 0.43, 0.82]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`ina$$], 1, "a"}, 0.01, 4, 0.01}, {{
       Hold[$CellContext`inb$$], 1, "b"}, 0.01, 4, 0.01}, {{
       Hold[$CellContext`inc$$], 1, "c"}, 0.01, 4, 0.01}, {{
       Hold[$CellContext`Opac$$], 1, "Opacity"}, 0, 1, 0.01}, {
      Hold[
       Style["Parameters of initial point", Bold, 
        RGBColor[0.15, 0.57, 0.55]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`uz$$], 0.5, "x0"}, 0.01, 0.99, 0.01}, {{
       Hold[$CellContext`vz$$], 0.5, "y0"}, 0.01, 0.99, 0.01}, {
      Hold[
       Style["Parameters of geodesics", Bold, 
        RGBColor[0.6, 0.73, 0.36]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`inm$$], 10, "Number of geodesics:"}, 1, 100, 1}, {{
       Hold[$CellContext`inl$$], 1, "Length:"}, 0.01, 30, 0.01}, {
      Hold[
       Style["OR", Bold, 
        RGBColor[0.6, 0.73, 0.36]]], Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Style["Parameters of direction", Bold, 
        RGBColor[0.6, 0.73, 0.36]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`ep$$], False, "Specify direction"}, {True, False}}, {{
       Hold[$CellContext`dir$$], 0.5, "Direction:"}, -3.1315926535897933`, 
      3.1315926535897933`, 0.01}}, Typeset`size$$ = {500., {248., 252.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`type$3016$$ = False, $CellContext`ina$3017$$ = 
    0, $CellContext`inb$3018$$ = 0, $CellContext`inc$3019$$ = 
    0, $CellContext`Opac$3020$$ = 0, $CellContext`uz$3021$$ = 
    0, $CellContext`vz$3022$$ = 0, $CellContext`inm$3023$$ = 
    0, $CellContext`inl$3024$$ = 0, $CellContext`ep$3025$$ = 
    False, $CellContext`dir$3026$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`dir$$ = 0.5, $CellContext`ep$$ = 
        False, $CellContext`ina$$ = 1, $CellContext`inb$$ = 
        1, $CellContext`inc$$ = 1, $CellContext`inl$$ = 1, $CellContext`inm$$ = 
        10, $CellContext`Opac$$ = 1, $CellContext`type$$ = 
        1, $CellContext`uz$$ = 0.5, $CellContext`vz$$ = 0.5}, 
      "ControllerVariables" :> {
        Hold[$CellContext`type$$, $CellContext`type$3016$$, False], 
        Hold[$CellContext`ina$$, $CellContext`ina$3017$$, 0], 
        Hold[$CellContext`inb$$, $CellContext`inb$3018$$, 0], 
        Hold[$CellContext`inc$$, $CellContext`inc$3019$$, 0], 
        Hold[$CellContext`Opac$$, $CellContext`Opac$3020$$, 0], 
        Hold[$CellContext`uz$$, $CellContext`uz$3021$$, 0], 
        Hold[$CellContext`vz$$, $CellContext`vz$3022$$, 0], 
        Hold[$CellContext`inm$$, $CellContext`inm$3023$$, 0], 
        Hold[$CellContext`inl$$, $CellContext`inl$3024$$, 0], 
        Hold[$CellContext`ep$$, $CellContext`ep$3025$$, False], 
        Hold[$CellContext`dir$$, $CellContext`dir$3026$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`Geodesics[$CellContext`type$$, \
$CellContext`ep$$, {$CellContext`uz$$, $CellContext`vz$$}, \
$CellContext`dir$$, $CellContext`inl$$, $CellContext`inm$$, \
$CellContext`ina$$, $CellContext`inb$$, $CellContext`inc$$, \
$CellContext`Opac$$], 
      "Specifications" :> {{{$CellContext`type$$, 1, "Select surface:"}, {
         1 -> "Monkey saddle", 2 -> "Torus", 3 -> "Helicoid", 4 -> 
          "Exponential twist", 5 -> "Sphere", 6 -> "Paraboloid", 7 -> 
          "Elipsoid", 8 -> "Funnel surface", 9 -> "Enneper surface", 10 -> 
          "Klein bottle (Beware! Long calculations)", 11 -> "Moebius strip"}, 
         ControlType -> PopupMenu, ControlPlacement -> Top}, Delimiter, 
        Style["Parameters of surface", Bold, 
         RGBColor[0.25, 0.43, 0.82]], {{$CellContext`ina$$, 1, "a"}, 0.01, 4, 
         0.01, Appearance -> "Labeled", ImageSize -> Tiny, Enabled :> Dynamic[
           Not[
            MemberQ[{1, 9, 10}, $CellContext`type$$]]]}, {{$CellContext`inb$$,
           1, "b"}, 0.01, 4, 0.01, Appearance -> "Labeled", ImageSize -> Tiny,
          Enabled :> Dynamic[
           Not[
            
            MemberQ[{1, 9, 10, 
             5}, $CellContext`type$$]]]}, {{$CellContext`inc$$, 1, "c"}, 0.01,
          4, 0.01, Appearance -> "Labeled", ImageSize -> Tiny, Enabled :> 
         Dynamic[
           Not[
            
            MemberQ[{1, 9, 10, 11, 5, 6, 
             8}, $CellContext`type$$]]]}, {{$CellContext`Opac$$, 1, 
          "Opacity"}, 0, 1, 0.01, Appearance -> "Labeled", ImageSize -> Tiny},
         Delimiter, 
        Style["Parameters of initial point", Bold, 
         RGBColor[0.15, 0.57, 0.55]], {{$CellContext`uz$$, 0.5, "x0"}, 0.01, 
         0.99, 0.01, Appearance -> "Labeled", ImageSize -> 
         Tiny}, {{$CellContext`vz$$, 0.5, "y0"}, 0.01, 0.99, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny}, Delimiter, 
        Style["Parameters of geodesics", Bold, 
         RGBColor[
         0.6, 0.73, 0.36]], {{$CellContext`inm$$, 10, "Number of geodesics:"},
          1, 100, 1, ImageSize -> Tiny, Appearance -> "Labeled", Enabled :> 
         Dynamic[
           Not[$CellContext`ep$$]]}, {{$CellContext`inl$$, 1, "Length:"}, 
         0.01, 30, 0.01, ImageSize -> Tiny, Appearance -> "Labeled"}, 
        Style["OR", Bold, 
         RGBColor[0.6, 0.73, 0.36]], 
        Style["Parameters of direction", Bold, 
         RGBColor[
         0.6, 0.73, 0.36]], {{$CellContext`ep$$, False, 
          "Specify direction"}, {
         True, False}}, {{$CellContext`dir$$, 0.5, 
          "Direction:"}, -3.1315926535897933`, 3.1315926535897933`, 0.01, 
         ImageSize -> Tiny, Appearance -> "Labeled", Enabled :> 
         Dynamic[$CellContext`ep$$]}}, 
      "Options" :> {
       ControlPlacement -> Left, AutorunSequencing -> {1, 2}, TrackedSymbols -> 
        True, ContinuousAction -> $CellContext`CA}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{801., {302., 307.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`Geodesics[
         Pattern[$CellContext`sh, 
          Blank[]], 
         Optional[
          Pattern[$CellContext`ep, 
           Blank[]], False], {
          Pattern[$CellContext`u0, 
           Blank[]], 
          Pattern[$CellContext`v0, 
           Blank[]]}, 
         Pattern[$CellContext`uk, 
          Blank[]], 
         Pattern[$CellContext`l, 
          Blank[]], 
         Pattern[$CellContext`m, 
          Blank[]], 
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]], 
         Pattern[$CellContext`Opac, 
          Blank[]]] := 
       Module[{$CellContext`sg, $CellContext`z0, $CellContext`z1, \
$CellContext`CA}, $CellContext`CA = True; 
         Switch[$CellContext`sh, 
           1, {$CellContext`x := $CellContext`monkeysaddle, $CellContext`uMin = \
-1, $CellContext`uMax = 1, $CellContext`vMin = -1, $CellContext`vMax = 1}, 
           2, {$CellContext`x := $CellContext`torus[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = -Pi, $CellContext`uMax = 
            Pi, $CellContext`vMin = -Pi, $CellContext`vMax = Pi}, 
           3, {$CellContext`x := $CellContext`helicoid[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = 0, $CellContext`uMax = 
            2 Pi, $CellContext`vMin = 0, $CellContext`vMax = 2}, 
           4, {$CellContext`x := $CellContext`exptwist[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = -Pi, $CellContext`uMax = 
            1, $CellContext`vMin = 0, $CellContext`vMax = 2}, 
           5, {$CellContext`x := $CellContext`sphere[$CellContext`a], \
$CellContext`uMin = -Pi, $CellContext`uMax = 
            Pi, $CellContext`vMin = -Pi, $CellContext`vMax = Pi}, 
           6, {$CellContext`x := $CellContext`paraboloid[$CellContext`a, \
$CellContext`b], $CellContext`uMin = -2, $CellContext`uMax = 
            2, $CellContext`vMin = -2, $CellContext`vMax = 2}, 
           7, {$CellContext`x := $CellContext`elipsoid[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = 0, $CellContext`uMax = 
            2 Pi, $CellContext`vMin = 0, $CellContext`vMax = 2 Pi}, 
           8, {$CellContext`x := $CellContext`funnel, $CellContext`uMin = 
            0, $CellContext`uMax = 2, $CellContext`vMin = 
            0, $CellContext`vMax = 2 Pi}, 
           9, {$CellContext`x := $CellContext`enneper, $CellContext`uMin = -
             Pi, $CellContext`uMax = 
            Pi, $CellContext`vMin = -Pi, $CellContext`vMax = Pi}, 
           10, {$CellContext`x := $CellContext`klein, $CellContext`uMin = 
            0, $CellContext`uMax = 2 Pi, $CellContext`vMin = 
            0, $CellContext`vMax = 2 Pi, $CellContext`CA = False}, 
           11, {$CellContext`x := $CellContext`moebius[$CellContext`a], \
$CellContext`uMin = -$CellContext`b, $CellContext`uMax = $CellContext`b, \
$CellContext`vMin = -Pi, $CellContext`vMax = Pi, 
            Null}]; $CellContext`x0 := $CellContext`uMin + $CellContext`u0 \
($CellContext`uMax - $CellContext`uMin); $CellContext`y0 := $CellContext`vMin + \
$CellContext`v0 ($CellContext`vMax - $CellContext`vMin); $CellContext`xe := \
$CellContext`uk; $CellContext`z0 = ParametricPlot3D[
            $CellContext`x[$CellContext`u, $CellContext`v], {$CellContext`u, \
$CellContext`uMin, $CellContext`uMax}, {$CellContext`v, $CellContext`vMin, \
$CellContext`vMax}, Axes -> False, Mesh -> None, PlotStyle -> {
              
              Opacity[$CellContext`Opac]}]; $CellContext`h = \
$CellContext`metric[$CellContext`x]; 
         If[$CellContext`ep, $CellContext`sg = \
$CellContext`solvegeoENDP[$CellContext`h, {$CellContext`x0, $CellContext`y0}, \
$CellContext`l, $CellContext`uk], {$CellContext`sg = \
$CellContext`solvegeo[$CellContext`h, {$CellContext`x0, $CellContext`y0}, \
$CellContext`l, $CellContext`m], $CellContext`CA = False}]; $CellContext`z1 = 
          ParametricPlot3D[
            Evaluate[
             ReplaceAll[
              $CellContext`x[
               $CellContext`u[$CellContext`t], 
               $CellContext`v[$CellContext`t]], $CellContext`sg]], \
{$CellContext`t, 0, $CellContext`l}, PlotStyle -> {
              Thickness[0.005]}, ColorFunction -> "DeepSeaColors"]; 
         Show[$CellContext`z0, $CellContext`z1, Boxed -> False, 
           ImageSize -> {500, 500}]], $CellContext`monkeysaddle[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`u, $CellContext`v, $CellContext`u^3 - 
         3 $CellContext`u $CellContext`v^2}, $CellContext`torus[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {
        Cos[$CellContext`v] ($CellContext`b + $CellContext`a 
           Cos[$CellContext`u]), 
         Sin[$CellContext`v] ($CellContext`b + $CellContext`a 
           Cos[$CellContext`u]), $CellContext`c 
         Sin[$CellContext`u]}, $CellContext`helicoid[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`a $CellContext`v 
         Cos[$CellContext`u], $CellContext`b $CellContext`v 
         Sin[$CellContext`u], $CellContext`c $CellContext`u}, \
$CellContext`exptwist[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`a $CellContext`v 
         Cos[$CellContext`u], $CellContext`a $CellContext`v 
         Sin[$CellContext`u], $CellContext`a 
         Exp[$CellContext`c $CellContext`u]}, $CellContext`sphere[
         Pattern[$CellContext`a, 
          Blank[]]] := $CellContext`torus[$CellContext`a, 
         0, $CellContext`a], $CellContext`paraboloid[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          
          Blank[]]] := {$CellContext`u, $CellContext`v, $CellContext`a \
$CellContext`u^2 + $CellContext`b $CellContext`v^2}, $CellContext`elipsoid[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`a Sin[$CellContext`u] 
         Cos[$CellContext`v], $CellContext`b Sin[$CellContext`u] 
         Sin[$CellContext`v], $CellContext`c 
         Cos[$CellContext`u]}, $CellContext`funnel[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] = {$CellContext`u Cos[$CellContext`v], $CellContext`u 
         Sin[$CellContext`v], 
         Log[$CellContext`u]}, $CellContext`enneper[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          
          Blank[]]] = {($CellContext`u (1 - $CellContext`u^2/
           3 + $CellContext`v^2))/
         3, -($CellContext`v (1 + $CellContext`u^2 - $CellContext`v^2/3))/
         3, ($CellContext`u^2 - $CellContext`v^2)/3}, $CellContext`klein[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] = {
        Cos[$CellContext`u] (3 + Cos[$CellContext`u/2] Sin[$CellContext`v] - 
          Sin[$CellContext`u/2] Sin[2 $CellContext`v]), 
         Sin[$CellContext`u] (3 + Cos[$CellContext`u/2] Sin[$CellContext`v] - 
          Sin[$CellContext`u/2] Sin[2 $CellContext`v]), 
         Sin[$CellContext`u/2] Sin[$CellContext`v] + 
         Cos[$CellContext`u/2] Sin[2 $CellContext`v]}, $CellContext`moebius[
         Pattern[$CellContext`a, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] = {($CellContext`a + $CellContext`u Cos[$CellContext`v/2])
           Cos[$CellContext`v], ($CellContext`a + $CellContext`u 
           Cos[$CellContext`v/2]) Sin[$CellContext`v], $CellContext`u 
         Sin[$CellContext`v/2]}, $CellContext`metric[
         Pattern[$CellContext`x, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := 
       Module[{$CellContext`xu, $CellContext`xv, $CellContext`U, \
$CellContext`V, $CellContext`si}, $CellContext`si = ReplaceAll[
            
            Simplify[#], {$CellContext`U -> $CellContext`u, $CellContext`V -> \
$CellContext`v}]& ; $CellContext`xu = D[
            $CellContext`x[$CellContext`U, $CellContext`V], $CellContext`U]; \
$CellContext`xv = D[
            $CellContext`x[$CellContext`U, $CellContext`V], $CellContext`V]; \
$CellContext`ee = $CellContext`si[
            
            Dot[$CellContext`xu, $CellContext`xu]]; $CellContext`ff = \
$CellContext`si[
            
            Dot[$CellContext`xu, $CellContext`xv]]; $CellContext`gg = \
$CellContext`si[
            
            Dot[$CellContext`xv, $CellContext`xv]]; {{$CellContext`ee, \
$CellContext`ff}, {$CellContext`ff, $CellContext`gg}}], \
$CellContext`solvegeoENDP[
         Pattern[$CellContext`x, 
          Blank[]], {
          Pattern[$CellContext`u0, 
           Blank[]], 
          Pattern[$CellContext`v0, 
           Blank[]]}, 
         Pattern[$CellContext`l, 
          Blank[]], 
         Pattern[$CellContext`theta, 
          Blank[]]] := 
       Module[{$CellContext`su, $CellContext`e, $CellContext`so}, \
$CellContext`G := $CellContext`christoff[$CellContext`x][$CellContext`u, \
$CellContext`v]; $CellContext`su = {$CellContext`u -> \
$CellContext`u[$CellContext`s], $CellContext`v -> \
$CellContext`v[$CellContext`s], $CellContext`p -> 
            Derivative[1][$CellContext`u][$CellContext`s], $CellContext`q -> 
            Derivative[1][$CellContext`v][$CellContext`s]}; $CellContext`e[
            Pattern[$CellContext`j, 
             Blank[]]] := ($CellContext`e[$CellContext`j] = 
           ReplaceAll[
            Part[$CellContext`G, $CellContext`j, 1, 1] $CellContext`p^2 + 
             2 Part[$CellContext`G, $CellContext`j, 1, 
                2] $CellContext`p $CellContext`q + 
             Part[$CellContext`G, $CellContext`j, 2, 
                2] $CellContext`q^2, $CellContext`su]); $CellContext`equic := \
{Derivative[2][$CellContext`u][$CellContext`s] + $CellContext`e[1] == 0, 
            Derivative[2][$CellContext`v][$CellContext`s] + $CellContext`e[2] == 
            0, $CellContext`u[0] == $CellContext`u0, $CellContext`v[
             0] == $CellContext`v0, Derivative[1][$CellContext`u][0] == 
            Cos[$CellContext`theta], Derivative[1][$CellContext`v][0] == 
            Sin[$CellContext`theta]}; 
         NDSolve[$CellContext`equic, {$CellContext`u, $CellContext`v}, \
{$CellContext`s, 0, $CellContext`l}, Method -> 
           "StiffnessSwitching"]], $CellContext`christoff[
         Pattern[$CellContext`M, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := Module[{$CellContext`A}, $CellContext`si = ReplaceAll[
            
            Simplify[#], {$CellContext`U -> $CellContext`u, $CellContext`V -> \
$CellContext`v}]& ; $CellContext`ee = Part[
            $CellContext`M[$CellContext`U, $CellContext`V], 1, 
            1]; $CellContext`ff = Part[
            $CellContext`M[$CellContext`U, $CellContext`V], 1, 
            2]; $CellContext`gg = Part[
            $CellContext`M[$CellContext`U, $CellContext`V], 2, 
            2]; $CellContext`A[1, 1, 1] = 
          D[$CellContext`ee, $CellContext`V] $CellContext`ff - 2 
           D[$CellContext`ff, $CellContext`U] $CellContext`ff + 
           D[$CellContext`ee, $CellContext`U] $CellContext`gg; $CellContext`A[
           2, 2, 2] = 
          D[$CellContext`gg, $CellContext`V] $CellContext`ee - 2 
           D[$CellContext`ff, $CellContext`V] $CellContext`ff + 
           D[$CellContext`gg, $CellContext`U] $CellContext`ff; $CellContext`A[
           2, 1, 1] = (-D[$CellContext`ee, $CellContext`V]) $CellContext`ee + 
           2 D[$CellContext`ff, $CellContext`U] $CellContext`ee - 
           D[$CellContext`ee, $CellContext`U] $CellContext`ff; $CellContext`A[
           1, 2, 2] = (-D[$CellContext`gg, $CellContext`V]) $CellContext`ff + 
           2 D[$CellContext`ff, $CellContext`V] $CellContext`gg - 
           D[$CellContext`gg, $CellContext`U] $CellContext`gg; $CellContext`A[
           1, 1, 2] = 
          D[$CellContext`ee, $CellContext`V] $CellContext`gg - 
           D[$CellContext`gg, $CellContext`U] $CellContext`ff; $CellContext`A[
           2, 1, 2] = (-D[$CellContext`ee, $CellContext`V]) $CellContext`ff + 
           D[$CellContext`gg, $CellContext`U] $CellContext`ee; $CellContext`A[
           1, 2, 1] = 0; $CellContext`A[2, 2, 1] = 0; $CellContext`A[
            Pattern[$CellContext`i, 
             Blank[]], 2, 1] = $CellContext`A[$CellContext`i, 1, 
            2]; $CellContext`gamma[
            Pattern[$CellContext`i, 
             Blank[]], 
            Pattern[$CellContext`j, 
             Blank[]], 
            Pattern[$CellContext`k, 
             
             Blank[]]] := $CellContext`si[$CellContext`A[$CellContext`i, \
$CellContext`j, $CellContext`k] ($CellContext`ee $CellContext`gg - \
$CellContext`ff^2)^(-1)/2]; Table[
           $CellContext`gamma[$CellContext`i, $CellContext`j, \
$CellContext`k], {$CellContext`i, 1, 2}, {$CellContext`j, 1, 
            2}, {$CellContext`k, 1, 2}]], 
       Attributes[Derivative] = {
        NHoldAll, ReadProtected}, $CellContext`solvegeo[
         Pattern[$CellContext`x, 
          Blank[]], {
          Pattern[$CellContext`u0, 
           Blank[]], 
          Pattern[$CellContext`v0, 
           Blank[]]}, 
         Pattern[$CellContext`l, 
          Blank[]], 
         Pattern[$CellContext`m, 
          Blank[]]] := 
       Module[{$CellContext`su, $CellContext`e, $CellContext`so}, \
$CellContext`G := $CellContext`christoff[$CellContext`x][$CellContext`u, \
$CellContext`v]; $CellContext`su = {$CellContext`u -> \
$CellContext`u[$CellContext`s], $CellContext`v -> \
$CellContext`v[$CellContext`s], $CellContext`p -> 
            Derivative[1][$CellContext`u][$CellContext`s], $CellContext`q -> 
            Derivative[1][$CellContext`v][$CellContext`s]}; $CellContext`e[
            Pattern[$CellContext`j, 
             Blank[]]] := ($CellContext`e[$CellContext`j] = 
           ReplaceAll[
            Part[$CellContext`G, $CellContext`j, 1, 1] $CellContext`p^2 + 
             2 Part[$CellContext`G, $CellContext`j, 1, 
                2] $CellContext`p $CellContext`q + 
             Part[$CellContext`G, $CellContext`j, 2, 
                2] $CellContext`q^2, $CellContext`su]); $CellContext`equic := \
{Derivative[2][$CellContext`u][$CellContext`s] + $CellContext`e[1] == 0, 
            Derivative[2][$CellContext`v][$CellContext`s] + $CellContext`e[2] == 
            0, $CellContext`u[0] == $CellContext`u0, $CellContext`v[
             0] == $CellContext`v0, Derivative[1][$CellContext`u][0] == 
            Cos[$CellContext`theta], Derivative[1][$CellContext`v][0] == 
            Sin[$CellContext`theta]}; $CellContext`so := 
          NDSolve[$CellContext`equic, {$CellContext`u, $CellContext`v}, \
{$CellContext`s, 0, $CellContext`l}]; Flatten[
           
           Table[$CellContext`so, {$CellContext`theta, 2 (Pi/$CellContext`m), 
             2 Pi, 2 (Pi/$CellContext`m)}], 1]]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellEditDuplicate->False,
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.605139597036276*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`dir$$ = 
    0.29840734641020683`, $CellContext`ep$$ = True, $CellContext`ina$$ = 
    1, $CellContext`inb$$ = 2.96, $CellContext`inc$$ = 1, $CellContext`inl$$ =
     30., $CellContext`inm$$ = 10, $CellContext`Opac$$ = 
    1, $CellContext`type$$ = 2, $CellContext`uz$$ = 0.5, $CellContext`vz$$ = 
    0.5, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`type$$], 1, "Select surface:"}, {
      1 -> "Monkey saddle", 2 -> "Torus", 3 -> "Helicoid", 4 -> 
       "Exponential twist", 5 -> "Sphere", 6 -> "Paraboloid", 7 -> "Elipsoid",
        8 -> "Funnel surface", 9 -> "Enneper surface", 10 -> 
       "Klein bottle (Beware! Long calculations)", 11 -> "Moebius strip"}}, {
      Hold[
       Style["Parameters of surface", Bold, 
        RGBColor[0.25, 0.43, 0.82]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`ina$$], 1, "a"}, 0.01, 4, 0.01}, {{
       Hold[$CellContext`inb$$], 1, "b"}, 0.01, 4, 0.01}, {{
       Hold[$CellContext`inc$$], 1, "c"}, 0.01, 4, 0.01}, {{
       Hold[$CellContext`Opac$$], 1, "Opacity"}, 0, 1, 0.01}, {
      Hold[
       Style["Parameters of initial point", Bold, 
        RGBColor[0.15, 0.57, 0.55]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`uz$$], 0.5, "x0"}, 0.01, 0.99, 0.01}, {{
       Hold[$CellContext`vz$$], 0.5, "y0"}, 0.01, 0.99, 0.01}, {
      Hold[
       Style["Parameters of geodesics", Bold, 
        RGBColor[0.6, 0.73, 0.36]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`inm$$], 10, "Number of geodesics:"}, 1, 100, 1}, {{
       Hold[$CellContext`inl$$], 1, "Length:"}, 0.01, 30, 0.01}, {
      Hold[
       Style["OR", Bold, 
        RGBColor[0.6, 0.73, 0.36]]], Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Style["Parameters of direction", Bold, 
        RGBColor[0.6, 0.73, 0.36]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`ep$$], False, "Specify direction"}, {True, False}}, {{
       Hold[$CellContext`dir$$], 0.5, "Direction:"}, -3.1315926535897933`, 
      3.1315926535897933`, 0.01}}, Typeset`size$$ = {500., {248., 252.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`type$3016$$ = False, $CellContext`ina$3017$$ = 
    0, $CellContext`inb$3018$$ = 0, $CellContext`inc$3019$$ = 
    0, $CellContext`Opac$3020$$ = 0, $CellContext`uz$3021$$ = 
    0, $CellContext`vz$3022$$ = 0, $CellContext`inm$3023$$ = 
    0, $CellContext`inl$3024$$ = 0, $CellContext`ep$3025$$ = 
    False, $CellContext`dir$3026$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`dir$$ = 0.5, $CellContext`ep$$ = 
        False, $CellContext`ina$$ = 1, $CellContext`inb$$ = 
        1, $CellContext`inc$$ = 1, $CellContext`inl$$ = 1, $CellContext`inm$$ = 
        10, $CellContext`Opac$$ = 1, $CellContext`type$$ = 
        1, $CellContext`uz$$ = 0.5, $CellContext`vz$$ = 0.5}, 
      "ControllerVariables" :> {
        Hold[$CellContext`type$$, $CellContext`type$3016$$, False], 
        Hold[$CellContext`ina$$, $CellContext`ina$3017$$, 0], 
        Hold[$CellContext`inb$$, $CellContext`inb$3018$$, 0], 
        Hold[$CellContext`inc$$, $CellContext`inc$3019$$, 0], 
        Hold[$CellContext`Opac$$, $CellContext`Opac$3020$$, 0], 
        Hold[$CellContext`uz$$, $CellContext`uz$3021$$, 0], 
        Hold[$CellContext`vz$$, $CellContext`vz$3022$$, 0], 
        Hold[$CellContext`inm$$, $CellContext`inm$3023$$, 0], 
        Hold[$CellContext`inl$$, $CellContext`inl$3024$$, 0], 
        Hold[$CellContext`ep$$, $CellContext`ep$3025$$, False], 
        Hold[$CellContext`dir$$, $CellContext`dir$3026$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`Geodesics[$CellContext`type$$, \
$CellContext`ep$$, {$CellContext`uz$$, $CellContext`vz$$}, \
$CellContext`dir$$, $CellContext`inl$$, $CellContext`inm$$, \
$CellContext`ina$$, $CellContext`inb$$, $CellContext`inc$$, \
$CellContext`Opac$$], 
      "Specifications" :> {{{$CellContext`type$$, 1, "Select surface:"}, {
         1 -> "Monkey saddle", 2 -> "Torus", 3 -> "Helicoid", 4 -> 
          "Exponential twist", 5 -> "Sphere", 6 -> "Paraboloid", 7 -> 
          "Elipsoid", 8 -> "Funnel surface", 9 -> "Enneper surface", 10 -> 
          "Klein bottle (Beware! Long calculations)", 11 -> "Moebius strip"}, 
         ControlType -> PopupMenu, ControlPlacement -> Top}, Delimiter, 
        Style["Parameters of surface", Bold, 
         RGBColor[0.25, 0.43, 0.82]], {{$CellContext`ina$$, 1, "a"}, 0.01, 4, 
         0.01, Appearance -> "Labeled", ImageSize -> Tiny, Enabled :> Dynamic[
           Not[
            MemberQ[{1, 9, 10}, $CellContext`type$$]]]}, {{$CellContext`inb$$,
           1, "b"}, 0.01, 4, 0.01, Appearance -> "Labeled", ImageSize -> Tiny,
          Enabled :> Dynamic[
           Not[
            
            MemberQ[{1, 9, 10, 
             5}, $CellContext`type$$]]]}, {{$CellContext`inc$$, 1, "c"}, 0.01,
          4, 0.01, Appearance -> "Labeled", ImageSize -> Tiny, Enabled :> 
         Dynamic[
           Not[
            
            MemberQ[{1, 9, 10, 11, 5, 6, 
             8}, $CellContext`type$$]]]}, {{$CellContext`Opac$$, 1, 
          "Opacity"}, 0, 1, 0.01, Appearance -> "Labeled", ImageSize -> Tiny},
         Delimiter, 
        Style["Parameters of initial point", Bold, 
         RGBColor[0.15, 0.57, 0.55]], {{$CellContext`uz$$, 0.5, "x0"}, 0.01, 
         0.99, 0.01, Appearance -> "Labeled", ImageSize -> 
         Tiny}, {{$CellContext`vz$$, 0.5, "y0"}, 0.01, 0.99, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny}, Delimiter, 
        Style["Parameters of geodesics", Bold, 
         RGBColor[
         0.6, 0.73, 0.36]], {{$CellContext`inm$$, 10, "Number of geodesics:"},
          1, 100, 1, ImageSize -> Tiny, Appearance -> "Labeled", Enabled :> 
         Dynamic[
           Not[$CellContext`ep$$]]}, {{$CellContext`inl$$, 1, "Length:"}, 
         0.01, 30, 0.01, ImageSize -> Tiny, Appearance -> "Labeled"}, 
        Style["OR", Bold, 
         RGBColor[0.6, 0.73, 0.36]], 
        Style["Parameters of direction", Bold, 
         RGBColor[
         0.6, 0.73, 0.36]], {{$CellContext`ep$$, False, 
          "Specify direction"}, {
         True, False}}, {{$CellContext`dir$$, 0.5, 
          "Direction:"}, -3.1315926535897933`, 3.1315926535897933`, 0.01, 
         ImageSize -> Tiny, Appearance -> "Labeled", Enabled :> 
         Dynamic[$CellContext`ep$$]}}, 
      "Options" :> {
       ControlPlacement -> Left, AutorunSequencing -> {1, 2}, TrackedSymbols -> 
        True, ContinuousAction -> $CellContext`CA}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{806., {302., 307.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`Geodesics[
         Pattern[$CellContext`sh, 
          Blank[]], 
         Optional[
          Pattern[$CellContext`ep, 
           Blank[]], False], {
          Pattern[$CellContext`u0, 
           Blank[]], 
          Pattern[$CellContext`v0, 
           Blank[]]}, 
         Pattern[$CellContext`uk, 
          Blank[]], 
         Pattern[$CellContext`l, 
          Blank[]], 
         Pattern[$CellContext`m, 
          Blank[]], 
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]], 
         Pattern[$CellContext`Opac, 
          Blank[]]] := 
       Module[{$CellContext`sg, $CellContext`z0, $CellContext`z1, \
$CellContext`CA}, $CellContext`CA = True; 
         Switch[$CellContext`sh, 
           1, {$CellContext`x := $CellContext`monkeysaddle, $CellContext`uMin = \
-1, $CellContext`uMax = 1, $CellContext`vMin = -1, $CellContext`vMax = 1}, 
           2, {$CellContext`x := $CellContext`torus[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = -Pi, $CellContext`uMax = 
            Pi, $CellContext`vMin = -Pi, $CellContext`vMax = Pi}, 
           3, {$CellContext`x := $CellContext`helicoid[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = 0, $CellContext`uMax = 
            2 Pi, $CellContext`vMin = 0, $CellContext`vMax = 2}, 
           4, {$CellContext`x := $CellContext`exptwist[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = -Pi, $CellContext`uMax = 
            1, $CellContext`vMin = 0, $CellContext`vMax = 2}, 
           5, {$CellContext`x := $CellContext`sphere[$CellContext`a], \
$CellContext`uMin = -Pi, $CellContext`uMax = 
            Pi, $CellContext`vMin = -Pi, $CellContext`vMax = Pi}, 
           6, {$CellContext`x := $CellContext`paraboloid[$CellContext`a, \
$CellContext`b], $CellContext`uMin = -2, $CellContext`uMax = 
            2, $CellContext`vMin = -2, $CellContext`vMax = 2}, 
           7, {$CellContext`x := $CellContext`elipsoid[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = 0, $CellContext`uMax = 
            2 Pi, $CellContext`vMin = 0, $CellContext`vMax = 2 Pi}, 
           8, {$CellContext`x := $CellContext`funnel, $CellContext`uMin = 
            0, $CellContext`uMax = 2, $CellContext`vMin = 
            0, $CellContext`vMax = 2 Pi}, 
           9, {$CellContext`x := $CellContext`enneper, $CellContext`uMin = -
             Pi, $CellContext`uMax = 
            Pi, $CellContext`vMin = -Pi, $CellContext`vMax = Pi}, 
           10, {$CellContext`x := $CellContext`klein, $CellContext`uMin = 
            0, $CellContext`uMax = 2 Pi, $CellContext`vMin = 
            0, $CellContext`vMax = 2 Pi, $CellContext`CA = False}, 
           11, {$CellContext`x := $CellContext`moebius[$CellContext`a], \
$CellContext`uMin = -$CellContext`b, $CellContext`uMax = $CellContext`b, \
$CellContext`vMin = -Pi, $CellContext`vMax = Pi, 
            Null}]; $CellContext`x0 := $CellContext`uMin + $CellContext`u0 \
($CellContext`uMax - $CellContext`uMin); $CellContext`y0 := $CellContext`vMin + \
$CellContext`v0 ($CellContext`vMax - $CellContext`vMin); $CellContext`xe := \
$CellContext`uk; $CellContext`z0 = ParametricPlot3D[
            $CellContext`x[$CellContext`u, $CellContext`v], {$CellContext`u, \
$CellContext`uMin, $CellContext`uMax}, {$CellContext`v, $CellContext`vMin, \
$CellContext`vMax}, Axes -> False, Mesh -> None, PlotStyle -> {
              
              Opacity[$CellContext`Opac]}]; $CellContext`h = \
$CellContext`metric[$CellContext`x]; 
         If[$CellContext`ep, $CellContext`sg = \
$CellContext`solvegeoENDP[$CellContext`h, {$CellContext`x0, $CellContext`y0}, \
$CellContext`l, $CellContext`uk], {$CellContext`sg = \
$CellContext`solvegeo[$CellContext`h, {$CellContext`x0, $CellContext`y0}, \
$CellContext`l, $CellContext`m], $CellContext`CA = False}]; $CellContext`z1 = 
          ParametricPlot3D[
            Evaluate[
             ReplaceAll[
              $CellContext`x[
               $CellContext`u[$CellContext`t], 
               $CellContext`v[$CellContext`t]], $CellContext`sg]], \
{$CellContext`t, 0, $CellContext`l}, PlotStyle -> {
              Thickness[0.005]}, ColorFunction -> "DeepSeaColors"]; 
         Show[$CellContext`z0, $CellContext`z1, Boxed -> False, 
           ImageSize -> {500, 500}]], $CellContext`monkeysaddle[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`u, $CellContext`v, $CellContext`u^3 - 
         3 $CellContext`u $CellContext`v^2}, $CellContext`torus[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {
        Cos[$CellContext`v] ($CellContext`b + $CellContext`a 
           Cos[$CellContext`u]), 
         Sin[$CellContext`v] ($CellContext`b + $CellContext`a 
           Cos[$CellContext`u]), $CellContext`c 
         Sin[$CellContext`u]}, $CellContext`helicoid[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`a $CellContext`v 
         Cos[$CellContext`u], $CellContext`b $CellContext`v 
         Sin[$CellContext`u], $CellContext`c $CellContext`u}, \
$CellContext`exptwist[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`a $CellContext`v 
         Cos[$CellContext`u], $CellContext`a $CellContext`v 
         Sin[$CellContext`u], $CellContext`a 
         Exp[$CellContext`c $CellContext`u]}, $CellContext`sphere[
         Pattern[$CellContext`a, 
          Blank[]]] := $CellContext`torus[$CellContext`a, 
         0, $CellContext`a], $CellContext`paraboloid[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          
          Blank[]]] := {$CellContext`u, $CellContext`v, $CellContext`a \
$CellContext`u^2 + $CellContext`b $CellContext`v^2}, $CellContext`elipsoid[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`a Sin[$CellContext`u] 
         Cos[$CellContext`v], $CellContext`b Sin[$CellContext`u] 
         Sin[$CellContext`v], $CellContext`c 
         Cos[$CellContext`u]}, $CellContext`funnel[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] = {$CellContext`u Cos[$CellContext`v], $CellContext`u 
         Sin[$CellContext`v], 
         Log[$CellContext`u]}, $CellContext`enneper[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          
          Blank[]]] = {($CellContext`u (1 - $CellContext`u^2/
           3 + $CellContext`v^2))/
         3, -($CellContext`v (1 + $CellContext`u^2 - $CellContext`v^2/3))/
         3, ($CellContext`u^2 - $CellContext`v^2)/3}, $CellContext`klein[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] = {
        Cos[$CellContext`u] (3 + Cos[$CellContext`u/2] Sin[$CellContext`v] - 
          Sin[$CellContext`u/2] Sin[2 $CellContext`v]), 
         Sin[$CellContext`u] (3 + Cos[$CellContext`u/2] Sin[$CellContext`v] - 
          Sin[$CellContext`u/2] Sin[2 $CellContext`v]), 
         Sin[$CellContext`u/2] Sin[$CellContext`v] + 
         Cos[$CellContext`u/2] Sin[2 $CellContext`v]}, $CellContext`moebius[
         Pattern[$CellContext`a, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] = {($CellContext`a + $CellContext`u Cos[$CellContext`v/2])
           Cos[$CellContext`v], ($CellContext`a + $CellContext`u 
           Cos[$CellContext`v/2]) Sin[$CellContext`v], $CellContext`u 
         Sin[$CellContext`v/2]}, $CellContext`metric[
         Pattern[$CellContext`x, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := 
       Module[{$CellContext`xu, $CellContext`xv, $CellContext`U, \
$CellContext`V, $CellContext`si}, $CellContext`si = ReplaceAll[
            
            Simplify[#], {$CellContext`U -> $CellContext`u, $CellContext`V -> \
$CellContext`v}]& ; $CellContext`xu = D[
            $CellContext`x[$CellContext`U, $CellContext`V], $CellContext`U]; \
$CellContext`xv = D[
            $CellContext`x[$CellContext`U, $CellContext`V], $CellContext`V]; \
$CellContext`ee = $CellContext`si[
            
            Dot[$CellContext`xu, $CellContext`xu]]; $CellContext`ff = \
$CellContext`si[
            
            Dot[$CellContext`xu, $CellContext`xv]]; $CellContext`gg = \
$CellContext`si[
            
            Dot[$CellContext`xv, $CellContext`xv]]; {{$CellContext`ee, \
$CellContext`ff}, {$CellContext`ff, $CellContext`gg}}], \
$CellContext`solvegeoENDP[
         Pattern[$CellContext`x, 
          Blank[]], {
          Pattern[$CellContext`u0, 
           Blank[]], 
          Pattern[$CellContext`v0, 
           Blank[]]}, 
         Pattern[$CellContext`l, 
          Blank[]], 
         Pattern[$CellContext`theta, 
          Blank[]]] := 
       Module[{$CellContext`su, $CellContext`e, $CellContext`so}, \
$CellContext`G := $CellContext`christoff[$CellContext`x][$CellContext`u, \
$CellContext`v]; $CellContext`su = {$CellContext`u -> \
$CellContext`u[$CellContext`s], $CellContext`v -> \
$CellContext`v[$CellContext`s], $CellContext`p -> 
            Derivative[1][$CellContext`u][$CellContext`s], $CellContext`q -> 
            Derivative[1][$CellContext`v][$CellContext`s]}; $CellContext`e[
            Pattern[$CellContext`j, 
             Blank[]]] := ($CellContext`e[$CellContext`j] = 
           ReplaceAll[
            Part[$CellContext`G, $CellContext`j, 1, 1] $CellContext`p^2 + 
             2 Part[$CellContext`G, $CellContext`j, 1, 
                2] $CellContext`p $CellContext`q + 
             Part[$CellContext`G, $CellContext`j, 2, 
                2] $CellContext`q^2, $CellContext`su]); $CellContext`equic := \
{Derivative[2][$CellContext`u][$CellContext`s] + $CellContext`e[1] == 0, 
            Derivative[2][$CellContext`v][$CellContext`s] + $CellContext`e[2] == 
            0, $CellContext`u[0] == $CellContext`u0, $CellContext`v[
             0] == $CellContext`v0, Derivative[1][$CellContext`u][0] == 
            Cos[$CellContext`theta], Derivative[1][$CellContext`v][0] == 
            Sin[$CellContext`theta]}; 
         NDSolve[$CellContext`equic, {$CellContext`u, $CellContext`v}, \
{$CellContext`s, 0, $CellContext`l}, Method -> 
           "StiffnessSwitching"]], $CellContext`christoff[
         Pattern[$CellContext`M, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := Module[{$CellContext`A}, $CellContext`si = ReplaceAll[
            
            Simplify[#], {$CellContext`U -> $CellContext`u, $CellContext`V -> \
$CellContext`v}]& ; $CellContext`ee = Part[
            $CellContext`M[$CellContext`U, $CellContext`V], 1, 
            1]; $CellContext`ff = Part[
            $CellContext`M[$CellContext`U, $CellContext`V], 1, 
            2]; $CellContext`gg = Part[
            $CellContext`M[$CellContext`U, $CellContext`V], 2, 
            2]; $CellContext`A[1, 1, 1] = 
          D[$CellContext`ee, $CellContext`V] $CellContext`ff - 2 
           D[$CellContext`ff, $CellContext`U] $CellContext`ff + 
           D[$CellContext`ee, $CellContext`U] $CellContext`gg; $CellContext`A[
           2, 2, 2] = 
          D[$CellContext`gg, $CellContext`V] $CellContext`ee - 2 
           D[$CellContext`ff, $CellContext`V] $CellContext`ff + 
           D[$CellContext`gg, $CellContext`U] $CellContext`ff; $CellContext`A[
           2, 1, 1] = (-D[$CellContext`ee, $CellContext`V]) $CellContext`ee + 
           2 D[$CellContext`ff, $CellContext`U] $CellContext`ee - 
           D[$CellContext`ee, $CellContext`U] $CellContext`ff; $CellContext`A[
           1, 2, 2] = (-D[$CellContext`gg, $CellContext`V]) $CellContext`ff + 
           2 D[$CellContext`ff, $CellContext`V] $CellContext`gg - 
           D[$CellContext`gg, $CellContext`U] $CellContext`gg; $CellContext`A[
           1, 1, 2] = 
          D[$CellContext`ee, $CellContext`V] $CellContext`gg - 
           D[$CellContext`gg, $CellContext`U] $CellContext`ff; $CellContext`A[
           2, 1, 2] = (-D[$CellContext`ee, $CellContext`V]) $CellContext`ff + 
           D[$CellContext`gg, $CellContext`U] $CellContext`ee; $CellContext`A[
           1, 2, 1] = 0; $CellContext`A[2, 2, 1] = 0; $CellContext`A[
            Pattern[$CellContext`i, 
             Blank[]], 2, 1] = $CellContext`A[$CellContext`i, 1, 
            2]; $CellContext`gamma[
            Pattern[$CellContext`i, 
             Blank[]], 
            Pattern[$CellContext`j, 
             Blank[]], 
            Pattern[$CellContext`k, 
             
             Blank[]]] := $CellContext`si[$CellContext`A[$CellContext`i, \
$CellContext`j, $CellContext`k] ($CellContext`ee $CellContext`gg - \
$CellContext`ff^2)^(-1)/2]; Table[
           $CellContext`gamma[$CellContext`i, $CellContext`j, \
$CellContext`k], {$CellContext`i, 1, 2}, {$CellContext`j, 1, 
            2}, {$CellContext`k, 1, 2}]], 
       Attributes[Derivative] = {
        NHoldAll, ReadProtected}, $CellContext`solvegeo[
         Pattern[$CellContext`x, 
          Blank[]], {
          Pattern[$CellContext`u0, 
           Blank[]], 
          Pattern[$CellContext`v0, 
           Blank[]]}, 
         Pattern[$CellContext`l, 
          Blank[]], 
         Pattern[$CellContext`m, 
          Blank[]]] := 
       Module[{$CellContext`su, $CellContext`e, $CellContext`so}, \
$CellContext`G := $CellContext`christoff[$CellContext`x][$CellContext`u, \
$CellContext`v]; $CellContext`su = {$CellContext`u -> \
$CellContext`u[$CellContext`s], $CellContext`v -> \
$CellContext`v[$CellContext`s], $CellContext`p -> 
            Derivative[1][$CellContext`u][$CellContext`s], $CellContext`q -> 
            Derivative[1][$CellContext`v][$CellContext`s]}; $CellContext`e[
            Pattern[$CellContext`j, 
             Blank[]]] := ($CellContext`e[$CellContext`j] = 
           ReplaceAll[
            Part[$CellContext`G, $CellContext`j, 1, 1] $CellContext`p^2 + 
             2 Part[$CellContext`G, $CellContext`j, 1, 
                2] $CellContext`p $CellContext`q + 
             Part[$CellContext`G, $CellContext`j, 2, 
                2] $CellContext`q^2, $CellContext`su]); $CellContext`equic := \
{Derivative[2][$CellContext`u][$CellContext`s] + $CellContext`e[1] == 0, 
            Derivative[2][$CellContext`v][$CellContext`s] + $CellContext`e[2] == 
            0, $CellContext`u[0] == $CellContext`u0, $CellContext`v[
             0] == $CellContext`v0, Derivative[1][$CellContext`u][0] == 
            Cos[$CellContext`theta], Derivative[1][$CellContext`v][0] == 
            Sin[$CellContext`theta]}; $CellContext`so := 
          NDSolve[$CellContext`equic, {$CellContext`u, $CellContext`v}, \
{$CellContext`s, 0, $CellContext`l}]; Flatten[
           
           Table[$CellContext`so, {$CellContext`theta, 2 (Pi/$CellContext`m), 
             2 Pi, 2 (Pi/$CellContext`m)}], 1]]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->279308973],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`dir$$ = 
    2.7884073464102066`, $CellContext`ep$$ = True, $CellContext`ina$$ = 
    1, $CellContext`inb$$ = 2.96, $CellContext`inc$$ = 1, $CellContext`inl$$ =
     30., $CellContext`inm$$ = 10, $CellContext`Opac$$ = 
    1, $CellContext`type$$ = 8, $CellContext`uz$$ = 0.5, $CellContext`vz$$ = 
    0.5, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`type$$], 1, "Select surface:"}, {
      1 -> "Monkey saddle", 2 -> "Torus", 3 -> "Helicoid", 4 -> 
       "Exponential twist", 5 -> "Sphere", 6 -> "Paraboloid", 7 -> "Elipsoid",
        8 -> "Funnel surface", 9 -> "Enneper surface", 10 -> 
       "Klein bottle (Beware! Long calculations)", 11 -> "Moebius strip"}}, {
      Hold[
       Style["Parameters of surface", Bold, 
        RGBColor[0.25, 0.43, 0.82]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`ina$$], 1, "a"}, 0.01, 4, 0.01}, {{
       Hold[$CellContext`inb$$], 1, "b"}, 0.01, 4, 0.01}, {{
       Hold[$CellContext`inc$$], 1, "c"}, 0.01, 4, 0.01}, {{
       Hold[$CellContext`Opac$$], 1, "Opacity"}, 0, 1, 0.01}, {
      Hold[
       Style["Parameters of initial point", Bold, 
        RGBColor[0.15, 0.57, 0.55]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`uz$$], 0.5, "x0"}, 0.01, 0.99, 0.01}, {{
       Hold[$CellContext`vz$$], 0.5, "y0"}, 0.01, 0.99, 0.01}, {
      Hold[
       Style["Parameters of geodesics", Bold, 
        RGBColor[0.6, 0.73, 0.36]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`inm$$], 10, "Number of geodesics:"}, 1, 100, 1}, {{
       Hold[$CellContext`inl$$], 1, "Length:"}, 0.01, 30, 0.01}, {
      Hold[
       Style["OR", Bold, 
        RGBColor[0.6, 0.73, 0.36]]], Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Style["Parameters of direction", Bold, 
        RGBColor[0.6, 0.73, 0.36]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`ep$$], False, "Specify direction"}, {True, False}}, {{
       Hold[$CellContext`dir$$], 0.5, "Direction:"}, -3.1315926535897933`, 
      3.1315926535897933`, 0.01}}, Typeset`size$$ = {500., {248., 252.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`type$3016$$ = False, $CellContext`ina$3017$$ = 
    0, $CellContext`inb$3018$$ = 0, $CellContext`inc$3019$$ = 
    0, $CellContext`Opac$3020$$ = 0, $CellContext`uz$3021$$ = 
    0, $CellContext`vz$3022$$ = 0, $CellContext`inm$3023$$ = 
    0, $CellContext`inl$3024$$ = 0, $CellContext`ep$3025$$ = 
    False, $CellContext`dir$3026$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`dir$$ = 0.5, $CellContext`ep$$ = 
        False, $CellContext`ina$$ = 1, $CellContext`inb$$ = 
        1, $CellContext`inc$$ = 1, $CellContext`inl$$ = 1, $CellContext`inm$$ = 
        10, $CellContext`Opac$$ = 1, $CellContext`type$$ = 
        1, $CellContext`uz$$ = 0.5, $CellContext`vz$$ = 0.5}, 
      "ControllerVariables" :> {
        Hold[$CellContext`type$$, $CellContext`type$3016$$, False], 
        Hold[$CellContext`ina$$, $CellContext`ina$3017$$, 0], 
        Hold[$CellContext`inb$$, $CellContext`inb$3018$$, 0], 
        Hold[$CellContext`inc$$, $CellContext`inc$3019$$, 0], 
        Hold[$CellContext`Opac$$, $CellContext`Opac$3020$$, 0], 
        Hold[$CellContext`uz$$, $CellContext`uz$3021$$, 0], 
        Hold[$CellContext`vz$$, $CellContext`vz$3022$$, 0], 
        Hold[$CellContext`inm$$, $CellContext`inm$3023$$, 0], 
        Hold[$CellContext`inl$$, $CellContext`inl$3024$$, 0], 
        Hold[$CellContext`ep$$, $CellContext`ep$3025$$, False], 
        Hold[$CellContext`dir$$, $CellContext`dir$3026$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`Geodesics[$CellContext`type$$, \
$CellContext`ep$$, {$CellContext`uz$$, $CellContext`vz$$}, \
$CellContext`dir$$, $CellContext`inl$$, $CellContext`inm$$, \
$CellContext`ina$$, $CellContext`inb$$, $CellContext`inc$$, \
$CellContext`Opac$$], 
      "Specifications" :> {{{$CellContext`type$$, 1, "Select surface:"}, {
         1 -> "Monkey saddle", 2 -> "Torus", 3 -> "Helicoid", 4 -> 
          "Exponential twist", 5 -> "Sphere", 6 -> "Paraboloid", 7 -> 
          "Elipsoid", 8 -> "Funnel surface", 9 -> "Enneper surface", 10 -> 
          "Klein bottle (Beware! Long calculations)", 11 -> "Moebius strip"}, 
         ControlType -> PopupMenu, ControlPlacement -> Top}, Delimiter, 
        Style["Parameters of surface", Bold, 
         RGBColor[0.25, 0.43, 0.82]], {{$CellContext`ina$$, 1, "a"}, 0.01, 4, 
         0.01, Appearance -> "Labeled", ImageSize -> Tiny, Enabled :> Dynamic[
           Not[
            MemberQ[{1, 9, 10}, $CellContext`type$$]]]}, {{$CellContext`inb$$,
           1, "b"}, 0.01, 4, 0.01, Appearance -> "Labeled", ImageSize -> Tiny,
          Enabled :> Dynamic[
           Not[
            
            MemberQ[{1, 9, 10, 
             5}, $CellContext`type$$]]]}, {{$CellContext`inc$$, 1, "c"}, 0.01,
          4, 0.01, Appearance -> "Labeled", ImageSize -> Tiny, Enabled :> 
         Dynamic[
           Not[
            
            MemberQ[{1, 9, 10, 11, 5, 6, 
             8}, $CellContext`type$$]]]}, {{$CellContext`Opac$$, 1, 
          "Opacity"}, 0, 1, 0.01, Appearance -> "Labeled", ImageSize -> Tiny},
         Delimiter, 
        Style["Parameters of initial point", Bold, 
         RGBColor[0.15, 0.57, 0.55]], {{$CellContext`uz$$, 0.5, "x0"}, 0.01, 
         0.99, 0.01, Appearance -> "Labeled", ImageSize -> 
         Tiny}, {{$CellContext`vz$$, 0.5, "y0"}, 0.01, 0.99, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny}, Delimiter, 
        Style["Parameters of geodesics", Bold, 
         RGBColor[
         0.6, 0.73, 0.36]], {{$CellContext`inm$$, 10, "Number of geodesics:"},
          1, 100, 1, ImageSize -> Tiny, Appearance -> "Labeled", Enabled :> 
         Dynamic[
           Not[$CellContext`ep$$]]}, {{$CellContext`inl$$, 1, "Length:"}, 
         0.01, 30, 0.01, ImageSize -> Tiny, Appearance -> "Labeled"}, 
        Style["OR", Bold, 
         RGBColor[0.6, 0.73, 0.36]], 
        Style["Parameters of direction", Bold, 
         RGBColor[
         0.6, 0.73, 0.36]], {{$CellContext`ep$$, False, 
          "Specify direction"}, {
         True, False}}, {{$CellContext`dir$$, 0.5, 
          "Direction:"}, -3.1315926535897933`, 3.1315926535897933`, 0.01, 
         ImageSize -> Tiny, Appearance -> "Labeled", Enabled :> 
         Dynamic[$CellContext`ep$$]}}, 
      "Options" :> {
       ControlPlacement -> Left, AutorunSequencing -> {1, 2}, TrackedSymbols -> 
        True, ContinuousAction -> $CellContext`CA}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{801., {302., 307.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`Geodesics[
         Pattern[$CellContext`sh, 
          Blank[]], 
         Optional[
          Pattern[$CellContext`ep, 
           Blank[]], False], {
          Pattern[$CellContext`u0, 
           Blank[]], 
          Pattern[$CellContext`v0, 
           Blank[]]}, 
         Pattern[$CellContext`uk, 
          Blank[]], 
         Pattern[$CellContext`l, 
          Blank[]], 
         Pattern[$CellContext`m, 
          Blank[]], 
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]], 
         Pattern[$CellContext`Opac, 
          Blank[]]] := 
       Module[{$CellContext`sg, $CellContext`z0, $CellContext`z1, \
$CellContext`CA}, $CellContext`CA = True; 
         Switch[$CellContext`sh, 
           1, {$CellContext`x := $CellContext`monkeysaddle, $CellContext`uMin = \
-1, $CellContext`uMax = 1, $CellContext`vMin = -1, $CellContext`vMax = 1}, 
           2, {$CellContext`x := $CellContext`torus[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = -Pi, $CellContext`uMax = 
            Pi, $CellContext`vMin = -Pi, $CellContext`vMax = Pi}, 
           3, {$CellContext`x := $CellContext`helicoid[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = 0, $CellContext`uMax = 
            2 Pi, $CellContext`vMin = 0, $CellContext`vMax = 2}, 
           4, {$CellContext`x := $CellContext`exptwist[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = -Pi, $CellContext`uMax = 
            1, $CellContext`vMin = 0, $CellContext`vMax = 2}, 
           5, {$CellContext`x := $CellContext`sphere[$CellContext`a], \
$CellContext`uMin = -Pi, $CellContext`uMax = 
            Pi, $CellContext`vMin = -Pi, $CellContext`vMax = Pi}, 
           6, {$CellContext`x := $CellContext`paraboloid[$CellContext`a, \
$CellContext`b], $CellContext`uMin = -2, $CellContext`uMax = 
            2, $CellContext`vMin = -2, $CellContext`vMax = 2}, 
           7, {$CellContext`x := $CellContext`elipsoid[$CellContext`a, \
$CellContext`b, $CellContext`c], $CellContext`uMin = 0, $CellContext`uMax = 
            2 Pi, $CellContext`vMin = 0, $CellContext`vMax = 2 Pi}, 
           8, {$CellContext`x := $CellContext`funnel, $CellContext`uMin = 
            0, $CellContext`uMax = 2, $CellContext`vMin = 
            0, $CellContext`vMax = 2 Pi}, 
           9, {$CellContext`x := $CellContext`enneper, $CellContext`uMin = -
             Pi, $CellContext`uMax = 
            Pi, $CellContext`vMin = -Pi, $CellContext`vMax = Pi}, 
           10, {$CellContext`x := $CellContext`klein, $CellContext`uMin = 
            0, $CellContext`uMax = 2 Pi, $CellContext`vMin = 
            0, $CellContext`vMax = 2 Pi, $CellContext`CA = False}, 
           11, {$CellContext`x := $CellContext`moebius[$CellContext`a], \
$CellContext`uMin = -$CellContext`b, $CellContext`uMax = $CellContext`b, \
$CellContext`vMin = -Pi, $CellContext`vMax = Pi, 
            Null}]; $CellContext`x0 := $CellContext`uMin + $CellContext`u0 \
($CellContext`uMax - $CellContext`uMin); $CellContext`y0 := $CellContext`vMin + \
$CellContext`v0 ($CellContext`vMax - $CellContext`vMin); $CellContext`xe := \
$CellContext`uk; $CellContext`z0 = ParametricPlot3D[
            $CellContext`x[$CellContext`u, $CellContext`v], {$CellContext`u, \
$CellContext`uMin, $CellContext`uMax}, {$CellContext`v, $CellContext`vMin, \
$CellContext`vMax}, Axes -> False, Mesh -> None, PlotStyle -> {
              
              Opacity[$CellContext`Opac]}]; $CellContext`h = \
$CellContext`metric[$CellContext`x]; 
         If[$CellContext`ep, $CellContext`sg = \
$CellContext`solvegeoENDP[$CellContext`h, {$CellContext`x0, $CellContext`y0}, \
$CellContext`l, $CellContext`uk], {$CellContext`sg = \
$CellContext`solvegeo[$CellContext`h, {$CellContext`x0, $CellContext`y0}, \
$CellContext`l, $CellContext`m], $CellContext`CA = False}]; $CellContext`z1 = 
          ParametricPlot3D[
            Evaluate[
             ReplaceAll[
              $CellContext`x[
               $CellContext`u[$CellContext`t], 
               $CellContext`v[$CellContext`t]], $CellContext`sg]], \
{$CellContext`t, 0, $CellContext`l}, PlotStyle -> {
              Thickness[0.005]}, ColorFunction -> "DeepSeaColors"]; 
         Show[$CellContext`z0, $CellContext`z1, Boxed -> False, 
           ImageSize -> {500, 500}]], $CellContext`monkeysaddle[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`u, $CellContext`v, $CellContext`u^3 - 
         3 $CellContext`u $CellContext`v^2}, $CellContext`torus[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {
        Cos[$CellContext`v] ($CellContext`b + $CellContext`a 
           Cos[$CellContext`u]), 
         Sin[$CellContext`v] ($CellContext`b + $CellContext`a 
           Cos[$CellContext`u]), $CellContext`c 
         Sin[$CellContext`u]}, $CellContext`helicoid[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`a $CellContext`v 
         Cos[$CellContext`u], $CellContext`b $CellContext`v 
         Sin[$CellContext`u], $CellContext`c $CellContext`u}, \
$CellContext`exptwist[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`a $CellContext`v 
         Cos[$CellContext`u], $CellContext`a $CellContext`v 
         Sin[$CellContext`u], $CellContext`a 
         Exp[$CellContext`c $CellContext`u]}, $CellContext`sphere[
         Pattern[$CellContext`a, 
          Blank[]]] := $CellContext`torus[$CellContext`a, 
         0, $CellContext`a], $CellContext`paraboloid[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          
          Blank[]]] := {$CellContext`u, $CellContext`v, $CellContext`a \
$CellContext`u^2 + $CellContext`b $CellContext`v^2}, $CellContext`elipsoid[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := {$CellContext`a Sin[$CellContext`u] 
         Cos[$CellContext`v], $CellContext`b Sin[$CellContext`u] 
         Sin[$CellContext`v], $CellContext`c 
         Cos[$CellContext`u]}, $CellContext`funnel[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] = {$CellContext`u Cos[$CellContext`v], $CellContext`u 
         Sin[$CellContext`v], 
         Log[$CellContext`u]}, $CellContext`enneper[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          
          Blank[]]] = {($CellContext`u (1 - $CellContext`u^2/
           3 + $CellContext`v^2))/
         3, -($CellContext`v (1 + $CellContext`u^2 - $CellContext`v^2/3))/
         3, ($CellContext`u^2 - $CellContext`v^2)/3}, $CellContext`klein[
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] = {
        Cos[$CellContext`u] (3 + Cos[$CellContext`u/2] Sin[$CellContext`v] - 
          Sin[$CellContext`u/2] Sin[2 $CellContext`v]), 
         Sin[$CellContext`u] (3 + Cos[$CellContext`u/2] Sin[$CellContext`v] - 
          Sin[$CellContext`u/2] Sin[2 $CellContext`v]), 
         Sin[$CellContext`u/2] Sin[$CellContext`v] + 
         Cos[$CellContext`u/2] Sin[2 $CellContext`v]}, $CellContext`moebius[
         Pattern[$CellContext`a, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] = {($CellContext`a + $CellContext`u Cos[$CellContext`v/2])
           Cos[$CellContext`v], ($CellContext`a + $CellContext`u 
           Cos[$CellContext`v/2]) Sin[$CellContext`v], $CellContext`u 
         Sin[$CellContext`v/2]}, $CellContext`metric[
         Pattern[$CellContext`x, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := 
       Module[{$CellContext`xu, $CellContext`xv, $CellContext`U, \
$CellContext`V, $CellContext`si}, $CellContext`si = ReplaceAll[
            
            Simplify[#], {$CellContext`U -> $CellContext`u, $CellContext`V -> \
$CellContext`v}]& ; $CellContext`xu = D[
            $CellContext`x[$CellContext`U, $CellContext`V], $CellContext`U]; \
$CellContext`xv = D[
            $CellContext`x[$CellContext`U, $CellContext`V], $CellContext`V]; \
$CellContext`ee = $CellContext`si[
            
            Dot[$CellContext`xu, $CellContext`xu]]; $CellContext`ff = \
$CellContext`si[
            
            Dot[$CellContext`xu, $CellContext`xv]]; $CellContext`gg = \
$CellContext`si[
            
            Dot[$CellContext`xv, $CellContext`xv]]; {{$CellContext`ee, \
$CellContext`ff}, {$CellContext`ff, $CellContext`gg}}], \
$CellContext`solvegeoENDP[
         Pattern[$CellContext`x, 
          Blank[]], {
          Pattern[$CellContext`u0, 
           Blank[]], 
          Pattern[$CellContext`v0, 
           Blank[]]}, 
         Pattern[$CellContext`l, 
          Blank[]], 
         Pattern[$CellContext`theta, 
          Blank[]]] := 
       Module[{$CellContext`su, $CellContext`e, $CellContext`so}, \
$CellContext`G := $CellContext`christoff[$CellContext`x][$CellContext`u, \
$CellContext`v]; $CellContext`su = {$CellContext`u -> \
$CellContext`u[$CellContext`s], $CellContext`v -> \
$CellContext`v[$CellContext`s], $CellContext`p -> 
            Derivative[1][$CellContext`u][$CellContext`s], $CellContext`q -> 
            Derivative[1][$CellContext`v][$CellContext`s]}; $CellContext`e[
            Pattern[$CellContext`j, 
             Blank[]]] := ($CellContext`e[$CellContext`j] = 
           ReplaceAll[
            Part[$CellContext`G, $CellContext`j, 1, 1] $CellContext`p^2 + 
             2 Part[$CellContext`G, $CellContext`j, 1, 
                2] $CellContext`p $CellContext`q + 
             Part[$CellContext`G, $CellContext`j, 2, 
                2] $CellContext`q^2, $CellContext`su]); $CellContext`equic := \
{Derivative[2][$CellContext`u][$CellContext`s] + $CellContext`e[1] == 0, 
            Derivative[2][$CellContext`v][$CellContext`s] + $CellContext`e[2] == 
            0, $CellContext`u[0] == $CellContext`u0, $CellContext`v[
             0] == $CellContext`v0, Derivative[1][$CellContext`u][0] == 
            Cos[$CellContext`theta], Derivative[1][$CellContext`v][0] == 
            Sin[$CellContext`theta]}; 
         NDSolve[$CellContext`equic, {$CellContext`u, $CellContext`v}, \
{$CellContext`s, 0, $CellContext`l}, Method -> 
           "StiffnessSwitching"]], $CellContext`christoff[
         Pattern[$CellContext`M, 
          Blank[]]][
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := Module[{$CellContext`A}, $CellContext`si = ReplaceAll[
            
            Simplify[#], {$CellContext`U -> $CellContext`u, $CellContext`V -> \
$CellContext`v}]& ; $CellContext`ee = Part[
            $CellContext`M[$CellContext`U, $CellContext`V], 1, 
            1]; $CellContext`ff = Part[
            $CellContext`M[$CellContext`U, $CellContext`V], 1, 
            2]; $CellContext`gg = Part[
            $CellContext`M[$CellContext`U, $CellContext`V], 2, 
            2]; $CellContext`A[1, 1, 1] = 
          D[$CellContext`ee, $CellContext`V] $CellContext`ff - 2 
           D[$CellContext`ff, $CellContext`U] $CellContext`ff + 
           D[$CellContext`ee, $CellContext`U] $CellContext`gg; $CellContext`A[
           2, 2, 2] = 
          D[$CellContext`gg, $CellContext`V] $CellContext`ee - 2 
           D[$CellContext`ff, $CellContext`V] $CellContext`ff + 
           D[$CellContext`gg, $CellContext`U] $CellContext`ff; $CellContext`A[
           2, 1, 1] = (-D[$CellContext`ee, $CellContext`V]) $CellContext`ee + 
           2 D[$CellContext`ff, $CellContext`U] $CellContext`ee - 
           D[$CellContext`ee, $CellContext`U] $CellContext`ff; $CellContext`A[
           1, 2, 2] = (-D[$CellContext`gg, $CellContext`V]) $CellContext`ff + 
           2 D[$CellContext`ff, $CellContext`V] $CellContext`gg - 
           D[$CellContext`gg, $CellContext`U] $CellContext`gg; $CellContext`A[
           1, 1, 2] = 
          D[$CellContext`ee, $CellContext`V] $CellContext`gg - 
           D[$CellContext`gg, $CellContext`U] $CellContext`ff; $CellContext`A[
           2, 1, 2] = (-D[$CellContext`ee, $CellContext`V]) $CellContext`ff + 
           D[$CellContext`gg, $CellContext`U] $CellContext`ee; $CellContext`A[
           1, 2, 1] = 0; $CellContext`A[2, 2, 1] = 0; $CellContext`A[
            Pattern[$CellContext`i, 
             Blank[]], 2, 1] = $CellContext`A[$CellContext`i, 1, 
            2]; $CellContext`gamma[
            Pattern[$CellContext`i, 
             Blank[]], 
            Pattern[$CellContext`j, 
             Blank[]], 
            Pattern[$CellContext`k, 
             
             Blank[]]] := $CellContext`si[$CellContext`A[$CellContext`i, \
$CellContext`j, $CellContext`k] ($CellContext`ee $CellContext`gg - \
$CellContext`ff^2)^(-1)/2]; Table[
           $CellContext`gamma[$CellContext`i, $CellContext`j, \
$CellContext`k], {$CellContext`i, 1, 2}, {$CellContext`j, 1, 
            2}, {$CellContext`k, 1, 2}]], 
       Attributes[Derivative] = {
        NHoldAll, ReadProtected}, $CellContext`solvegeo[
         Pattern[$CellContext`x, 
          Blank[]], {
          Pattern[$CellContext`u0, 
           Blank[]], 
          Pattern[$CellContext`v0, 
           Blank[]]}, 
         Pattern[$CellContext`l, 
          Blank[]], 
         Pattern[$CellContext`m, 
          Blank[]]] := 
       Module[{$CellContext`su, $CellContext`e, $CellContext`so}, \
$CellContext`G := $CellContext`christoff[$CellContext`x][$CellContext`u, \
$CellContext`v]; $CellContext`su = {$CellContext`u -> \
$CellContext`u[$CellContext`s], $CellContext`v -> \
$CellContext`v[$CellContext`s], $CellContext`p -> 
            Derivative[1][$CellContext`u][$CellContext`s], $CellContext`q -> 
            Derivative[1][$CellContext`v][$CellContext`s]}; $CellContext`e[
            Pattern[$CellContext`j, 
             Blank[]]] := ($CellContext`e[$CellContext`j] = 
           ReplaceAll[
            Part[$CellContext`G, $CellContext`j, 1, 1] $CellContext`p^2 + 
             2 Part[$CellContext`G, $CellContext`j, 1, 
                2] $CellContext`p $CellContext`q + 
             Part[$CellContext`G, $CellContext`j, 2, 
                2] $CellContext`q^2, $CellContext`su]); $CellContext`equic := \
{Derivative[2][$CellContext`u][$CellContext`s] + $CellContext`e[1] == 0, 
            Derivative[2][$CellContext`v][$CellContext`s] + $CellContext`e[2] == 
            0, $CellContext`u[0] == $CellContext`u0, $CellContext`v[
             0] == $CellContext`v0, Derivative[1][$CellContext`u][0] == 
            Cos[$CellContext`theta], Derivative[1][$CellContext`v][0] == 
            Sin[$CellContext`theta]}; $CellContext`so := 
          NDSolve[$CellContext`equic, {$CellContext`u, $CellContext`v}, \
{$CellContext`s, 0, $CellContext`l}]; Flatten[
           
           Table[$CellContext`so, {$CellContext`theta, 2 (Pi/$CellContext`m), 
             2 Pi, 2 (Pi/$CellContext`m)}], 1]]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->26609282]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "DetailsSection"],

Cell[TextData[{
 "E. Abbena, S. Salamon, A. Gray,",
 StyleBox[" Modern Differential Geometry of Curves and Surfaces with \
Mathematica, Third Edition, ",
  FontSlant->"Italic"],
 "Chapman and Hall/CRC, 2006"
}], "DetailNotes",
 CellID->358973219]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ControlSuggestionsSection"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Resize Images"]}],
  "\"Click inside an image to reveal its orange resize frame.\\nDrag any of \
the orange resize handles to resize the image.\"",
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"ResizeImages"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Rotate and Zoom in 3D"]}],
  RowBox[{
   "\"Drag a 3D graphic to rotate it. Starting the drag near the center \
tumbles\\nthe graphic; starting near a corner turns it parallel to the plane \
of the screen.\\nHold down \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" (or \"", 
    FrameBox[
    "Cmd", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" on Mac) and drag up and down to zoom.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"RotateAndZoomIn3D"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Drag Locators"]}],
  RowBox[{"\"Drag any locator (\"", 
    GraphicsBox[
     LocatorBox[
      Scaled[{0.5, 0.5}]], ImageSize -> 20], 
    "\", etc.) to move it around.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"DragLocators"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Create and Delete Locators"]}],
  RowBox[{"\"Insert a new locator in the graphic by holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key\\nand clicking where you want it to be. Delete a locator by \
clicking it\\nwhile holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" key.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"CreateAndDeleteLocators"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Slider Zoom"]}],
  RowBox[{"\"Hold down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key while moving a slider to make fine adjustments in the slider \
value.\\nHold \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" and/or \"", 
    FrameBox[
    "Shift", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" at the same time as \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" to make ever finer adjustments.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"SliderZoom"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Gamepad Controls"]}],
  "\"Control this Demonstration with a gamepad or other\\nhuman interface \
device connected to your computer.\"",
  TooltipDelay->0.35]], "ControlSuggestions",
 CellChangeTimes->{3.35696210375764*^9, 3.3895522232313623`*^9},
 FontFamily->"Verdana",
 CellTags->"GamepadControls"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Automatic Animation"]}],
  RowBox[{"\"Animate a slider in this Demonstration by clicking the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIKwAgOI/R/IhBKc\n\
/4EAyGAG0f+nTZsGwgysIJIRKsWKLAXGIHFmEpUgLADxWUAkI24jZs+eTaEt\n\
IG+wQKRmzJgBlYf5lhEA30OqWA=="], "Graphics", ImageSize -> {9, 9}, ImageMargins -> 
      0, CellBaseline -> Baseline], BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"button\\nnext to the slider, and then clicking the play button that \
appears.\\nAnimate all controls by selecting \"", 
    StyleBox["Autorun", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"AutomaticAnimation"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Bookmark Animation"]}],
  RowBox[{
   "\"See a prepared animation of this Demonstration by selecting\\n\"", 
    StyleBox["Animate Bookmarks", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"BookmarkAnimation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SearchTermsSection"],

Cell["geodesics", "SearchTerms",
 CellChangeTimes->{{3.6051380887975874`*^9, 3.6051380921560135`*^9}},
 CellID->400624212],

Cell["differential geometry", "SearchTerms",
 CellChangeTimes->{{3.6051380887975874`*^9, 3.6051380992529163`*^9}},
 CellID->2940651],

Cell["curves", "SearchTerms",
 CellChangeTimes->{{3.6051380887975874`*^9, 3.6051381010011373`*^9}},
 CellID->279775489],

Cell["surfaces", "SearchTerms",
 CellChangeTimes->{{3.6051380887975874`*^9, 3.605138119006426*^9}},
 CellID->4730211],

Cell["manifold", "SearchTerms",
 CellChangeTimes->{{3.6051380887975874`*^9, 3.6051381069298906`*^9}, {
  3.6051384451688795`*^9, 3.60513844517188*^9}},
 CellID->118736674],

Cell["Christoffel Coefficients", "SearchTerms",
 CellChangeTimes->{{3.6051380887975874`*^9, 3.6051381069298906`*^9}, {
  3.6051384451688795`*^9, 3.6051384522667813`*^9}},
 CellID->75746872]
}, Open  ]],

Cell["", "RelatedLinksSection"],

Cell[CellGroupData[{

Cell["", "AuthorSection"],

Cell["Contributed by: Jan G\:0105ska", "Author",
 CellChangeTimes->{{3.6051395600445747`*^9, 3.605139561850804*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1264, 703},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (November 20, 2012)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Demonstration.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "ResizeImages"->{
  Cell[172779, 3813, 312, 8, 22, "ControlSuggestions",
   CellTags->"ResizeImages"]},
 "RotateAndZoomIn3D"->{
  Cell[173094, 3823, 678, 16, 22, "ControlSuggestions",
   CellTags->"RotateAndZoomIn3D"]},
 "DragLocators"->{
  Cell[173775, 3841, 340, 11, 22, "ControlSuggestions",
   CellTags->"DragLocators"]},
 "CreateAndDeleteLocators"->{
  Cell[174118, 3854, 637, 15, 22, "ControlSuggestions",
   CellTags->"CreateAndDeleteLocators"]},
 "SliderZoom"->{
  Cell[174758, 3871, 844, 21, 22, "ControlSuggestions",
   CellTags->"SliderZoom"]},
 "GamepadControls"->{
  Cell[175605, 3894, 369, 9, 22, "ControlSuggestions",
   CellTags->"GamepadControls"]},
 "AutomaticAnimation"->{
  Cell[175977, 3905, 1464, 31, 22, "ControlSuggestions",
   CellTags->"AutomaticAnimation"]},
 "BookmarkAnimation"->{
  Cell[177444, 3938, 908, 21, 22, "ControlSuggestions",
   CellTags->"BookmarkAnimation"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"ResizeImages", 179905, 4015},
 {"RotateAndZoomIn3D", 180015, 4018},
 {"DragLocators", 180126, 4021},
 {"CreateAndDeleteLocators", 180243, 4024},
 {"SliderZoom", 180358, 4027},
 {"GamepadControls", 180465, 4030},
 {"AutomaticAnimation", 180579, 4033},
 {"BookmarkAnimation", 180697, 4036}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 110, 3, 74, "DemoTitle"],
Cell[CellGroupData[{
Cell[714, 29, 33, 0, 287, "InitializationSection"],
Cell[750, 31, 40296, 1071, 3852, "Input",
 InitializationCell->True,
 CellID->833127212]
}, Open  ]],
Cell[CellGroupData[{
Cell[41083, 1107, 29, 0, 236, "ManipulateSection"],
Cell[CellGroupData[{
Cell[41137, 1111, 7825, 185, 648, "Input"],
Cell[48965, 1298, 28024, 558, 621, "Output",
 CellID->110791267]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[77038, 1862, 36, 0, 169, "ManipulateCaptionSection"],
Cell[77077, 1864, 595, 8, 56, "ManipulateCaption"]
}, Open  ]],
Cell[CellGroupData[{
Cell[77709, 1877, 28, 0, 173, "ThumbnailSection"],
Cell[77740, 1879, 23703, 477, 621, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101480, 2361, 28, 0, 143, "SnapshotsSection"],
Cell[101511, 2363, 23677, 477, 621, "Output"],
Cell[125191, 2842, 23599, 474, 621, "Output",
 CellID->279308973],
Cell[148793, 3318, 23597, 474, 621, "Output",
 CellID->26609282]
}, Open  ]],
Cell[CellGroupData[{
Cell[172427, 3797, 26, 0, 336, "DetailsSection"],
Cell[172456, 3799, 246, 7, 22, "DetailNotes",
 CellID->358973219]
}, Open  ]],
Cell[CellGroupData[{
Cell[172739, 3811, 37, 0, 126, "ControlSuggestionsSection"],
Cell[172779, 3813, 312, 8, 22, "ControlSuggestions",
 CellTags->"ResizeImages"],
Cell[173094, 3823, 678, 16, 22, "ControlSuggestions",
 CellTags->"RotateAndZoomIn3D"],
Cell[173775, 3841, 340, 11, 22, "ControlSuggestions",
 CellTags->"DragLocators"],
Cell[174118, 3854, 637, 15, 22, "ControlSuggestions",
 CellTags->"CreateAndDeleteLocators"],
Cell[174758, 3871, 844, 21, 22, "ControlSuggestions",
 CellTags->"SliderZoom"],
Cell[175605, 3894, 369, 9, 22, "ControlSuggestions",
 CellTags->"GamepadControls"],
Cell[175977, 3905, 1464, 31, 22, "ControlSuggestions",
 CellTags->"AutomaticAnimation"],
Cell[177444, 3938, 908, 21, 22, "ControlSuggestions",
 CellTags->"BookmarkAnimation"]
}, Open  ]],
Cell[CellGroupData[{
Cell[178389, 3964, 30, 0, 155, "SearchTermsSection"],
Cell[178422, 3966, 122, 2, 22, "SearchTerms",
 CellID->400624212],
Cell[178547, 3970, 132, 2, 22, "SearchTerms",
 CellID->2940651],
Cell[178682, 3974, 119, 2, 22, "SearchTerms",
 CellID->279775489],
Cell[178804, 3978, 117, 2, 22, "SearchTerms",
 CellID->4730211],
Cell[178924, 3982, 171, 3, 22, "SearchTerms",
 CellID->118736674],
Cell[179098, 3987, 189, 3, 22, "SearchTerms",
 CellID->75746872]
}, Open  ]],
Cell[179302, 3993, 31, 0, 141, "RelatedLinksSection"],
Cell[CellGroupData[{
Cell[179358, 3997, 25, 0, 129, "AuthorSection"],
Cell[179386, 3999, 116, 1, 22, "Author"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
